"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = Button;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _AppContext = require("../AppContext");

var _transition = require("../../utilities/transition");

var _Spinner = require("../Spinner");

var _Link = require("../Link");

var _legacy = require("../../utilities/legacy");

var _mediaQuery = require("../../utilities/media-query");

var _Connected = require("../Connected");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Button = _interopRequireDefault(require("./Button.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function Button(_ref) {
  var children = _ref.children,
      _ref$submit = _ref.submit,
      submit = _ref$submit === void 0 ? false : _ref$submit,
      disabled = _ref.disabled,
      onPress = _ref.onPress,
      to = _ref.to,
      subdued = _ref.subdued,
      plain = _ref.plain,
      secondary = _ref.secondary,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? false : _ref$loading,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? false : _ref$fill,
      loadingLabel = _ref.loadingLabel,
      underline = _ref.underline;
  var href = disabled ? undefined : to;
  var onClick = disabled ? undefined : function () {
    return onPress === null || onPress === void 0 ? void 0 : onPress();
  };
  var translate = (0, _AppContext.useTranslate)();
  var prefersReducedMotion = (0, _mediaQuery.usePrefersReducedMotion)();
  var transition = (0, _transition.useTransition)(loading, {
    enter: 'slow'
  });
  var connected = (0, _Connected.useConnected)();

  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.primaryButton,
      primaryStyle = _useThemeConfiguratio2.typographyStyle,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.loadingStyle,
      primaryLoading = _useThemeConfiguratio3 === void 0 ? 'spinner' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio.secondaryButton,
      secondaryStyle = _useThemeConfiguratio4.typographyStyle,
      _useThemeConfiguratio5 = _useThemeConfiguratio4.loadingStyle,
      secondaryLoading = _useThemeConfiguratio5 === void 0 ? 'spinner' : _useThemeConfiguratio5;

  var loadingStyle = secondary ? secondaryLoading : primaryLoading;
  var classes = (0, _cssUtilities.classNames)(_Button["default"].Button, _legacy.button, subdued && _Button["default"].isSubdued, plain && _Button["default"].isPlain, plain && underline && _Button["default"].isUnderline, disabled && _Button["default"].isDisabled, loading && loadingStyle === 'spinner' && _Button["default"].isLoading, fill && _Button["default"].isFill, loading && loadingStyle === 'spinner' && _Button["default"][(0, _cssUtilities.variationName)('isLoading-transition', transition)], connected && _Button["default"].isConnected, secondary && _Button["default"].isSecondary, loading && loadingStyle === 'progressBar' && _Button["default"][loadingStyle]);
  var normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  var contentTypography = secondary ? secondaryStyle && _typographyStyles["default"][secondaryStyle] : primaryStyle && _typographyStyles["default"][primaryStyle];

  var content = /*#__PURE__*/_react["default"].createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button["default"].Content, contentTypography)
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);

  var type = submit ? 'submit' : 'button';

  var loadingMarkup = /*#__PURE__*/_react["default"].createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button["default"].LoadingContent, !prefersReducedMotion && _Button["default"].Spinner)
  }, /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, {
    size: "small",
    color: "inherit"
  }, normalizedLoadingLabel));

  if (href) {
    return /*#__PURE__*/_react["default"].createElement(_Link.UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress
    }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
  }

  return /*#__PURE__*/_react["default"].createElement("button", {
    type: type,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading
  }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
}