"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Field = exports.TextField = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _VisuallyHidden = require("../VisuallyHidden");

var _Labelled = require("../Labelled");

var _Text = require("../Text");

var _Tooltip = require("../Tooltip");

var _InlineError = require("../InlineError");

var _BlockStack = require("../BlockStack");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _strings = require("../../utilities/strings");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _autocomplete = require("../../utilities/autocomplete");

var _TextField = _interopRequireDefault(require("./TextField.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var createId = (0, _id.createIdCreator)('TextField');

/**
 * A text field is an input field that merchants can type into.
 */
var TextField = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.textFields,
      labelPosition = _useThemeConfiguratio2.labelPosition,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.background,
      background = _useThemeConfiguratio3 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio3,
      errorIndentation = _useThemeConfiguratio2.errorIndentation,
      errorTypographyStyle = _useThemeConfiguratio2.errorTypographyStyle;

  var accessibilityDescription = props.accessibilityDescription,
      error = props.error,
      explicitId = props.id,
      label = props.label,
      tooltip = props.tooltip,
      explicitValue = props.value;
  var id = (0, _id.useId)(explicitId, createId);
  var descriptionId = accessibilityDescription ? "".concat(id, "-description") : undefined;
  var description = descriptionId ? /*#__PURE__*/_react["default"].createElement(_VisuallyHidden.VisuallyHidden, null, /*#__PURE__*/_react["default"].createElement(_Text.Text, {
    id: descriptionId
  }, accessibilityDescription)) : null;

  var errorMarkup = error && /*#__PURE__*/_react["default"].createElement("span", {
    className: (0, _cssUtilities.classNames)(errorIndentation && _TextField["default"][(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles["default"][errorTypographyStyle])
  }, /*#__PURE__*/_react["default"].createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  var tooltipMarkup = tooltip ? /*#__PURE__*/_react["default"].createElement("div", {
    className: _TextField["default"].Tooltip
  }, /*#__PURE__*/_react["default"].createElement(_Tooltip.Tooltip, {
    content: tooltip.content
  }, /*#__PURE__*/_react["default"].createElement(_VisuallyHidden.VisuallyHidden, null, tooltip.label), /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    source: "questionFill",
    size: "large",
    color: "subdued"
  }))) : null;
  return /*#__PURE__*/_react["default"].createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, {
    label: label,
    htmlFor: id,
    isEmpty: (0, _strings.isEmptyString)(explicitValue),
    position: labelPosition,
    background: background,
    subdued: props.readonly
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: _TextField["default"].Wrapper
  }, description, /*#__PURE__*/_react["default"].createElement(Field, Object.assign({
    ref: ref
  }, props, {
    id: id,
    ariaDescribedBy: descriptionId
  })), tooltipMarkup)), errorMarkup);
});
exports.TextField = TextField;
var Field = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, ref) {
  var id = _ref.id,
      name = _ref.name,
      label = _ref.label,
      explicitValue = _ref.value,
      controlledValue = _ref.controlledValue,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      role = _ref.role,
      required = _ref.required,
      error = _ref.error,
      tooltip = _ref.tooltip,
      autocomplete = _ref.autocomplete,
      autofocus = _ref.autofocus,
      multiline = _ref.multiline,
      disabled = _ref.disabled,
      readonly = _ref.readonly,
      ariaActiveDescendant = _ref.ariaActiveDescendant,
      ariaAutocomplete = _ref.ariaAutocomplete,
      ariaControls = _ref.ariaControls,
      ariaDescribedBy = _ref.ariaDescribedBy,
      ariaExpanded = _ref.ariaExpanded,
      _onFocus = _ref.onFocus,
      _onBlur = _ref.onBlur,
      _onChange = _ref.onChange,
      _onInput = _ref.onInput,
      onKeyDown = _ref.onKeyDown;
  var innerRef = (0, _react.useRef)();
  var refsSetter = (0, _react.useCallback)(function (instance) {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }

    innerRef.current = instance;
  }, [ref]);
  (0, _react.useEffect)(function () {
    if (autofocus) {
      var _innerRef$current;

      (_innerRef$current = innerRef.current) === null || _innerRef$current === void 0 ? void 0 : _innerRef$current.focus();
    }
  }, [autofocus]);

  var _useThemeConfiguratio4 = (0, _Theme.useThemeConfiguration)(),
      _useThemeConfiguratio5 = _useThemeConfiguratio4.textFields,
      _useThemeConfiguratio6 = _useThemeConfiguratio5.labelPosition,
      labelPosition = _useThemeConfiguratio6 === void 0 ? 'inside' : _useThemeConfiguratio6,
      _useThemeConfiguratio7 = _useThemeConfiguratio5.background,
      background = _useThemeConfiguratio7 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio7,
      _useThemeConfiguratio8 = _useThemeConfiguratio5.border,
      border = _useThemeConfiguratio8 === void 0 ? 'full' : _useThemeConfiguratio8,
      _useThemeConfiguratio9 = _useThemeConfiguratio5.borderColor,
      borderColor = _useThemeConfiguratio9 === void 0 ? 'base' : _useThemeConfiguratio9,
      _useThemeConfiguratio10 = _useThemeConfiguratio5.focusBorder,
      focusBorder = _useThemeConfiguratio10 === void 0 ? 'full' : _useThemeConfiguratio10,
      style = _useThemeConfiguratio5.typographyStyle;

  var labelled = (0, _Labelled.useLabelled)();

  var _usePartiallyControll = usePartiallyControlledState(controlledValue !== null && controlledValue !== void 0 ? controlledValue : explicitValue),
      _usePartiallyControll2 = _slicedToArray(_usePartiallyControll, 2),
      localValue = _usePartiallyControll2[0],
      setLocalValue = _usePartiallyControll2[1];

  var className = (0, _cssUtilities.classNames)(_TextField["default"].Field, Boolean(error) && _TextField["default"].hasError, Boolean(tooltip) && _TextField["default"]['Field-hasTooltip'], labelled.isFloating && labelPosition !== 'outside' && _TextField["default"]['Field-isFloating'], disabled && _TextField["default"]['Field-isDisabled'], readonly && _TextField["default"]['Field-isReadOnly'], _TextField["default"][(0, _cssUtilities.variationName)('Field-background', background)], _TextField["default"][(0, _cssUtilities.variationName)('Field-border', border)], _TextField["default"][(0, _cssUtilities.variationName)('Field-borderColor', borderColor)], _TextField["default"][(0, _cssUtilities.variationName)('Field-focusBorder', focusBorder)], style && _typographyStyles["default"][style]);
  var finalDescribedBy = [ariaDescribedBy, error && (0, _errors.errorId)(id)].filter(Boolean).join(' ');

  var field = /*#__PURE__*/_react["default"].createElement(multiline ? 'textarea' : 'input', {
    id: id,
    name: name,
    placeholder: labelled.isFloating || labelPosition === 'outside' ? undefined : label,
    className: className,
    required: required,
    type: normalizeType(multiline ? undefined : type),
    disabled: disabled,
    readOnly: readonly,
    'aria-activedescendant': ariaActiveDescendant,
    'aria-autocomplete': ariaAutocomplete,
    'aria-controls': ariaControls,
    'aria-describedby': finalDescribedBy,
    'aria-expanded': ariaExpanded,
    'aria-invalid': Boolean(error),
    'aria-required': required,
    onBlur: function onBlur() {
      _onBlur === null || _onBlur === void 0 ? void 0 : _onBlur();
      labelled.onBlur();
    },
    onInput: function onInput(_ref2) {
      var value = _ref2.currentTarget.value;
      setLocalValue(value);
      _onInput === null || _onInput === void 0 ? void 0 : _onInput(value);
      labelled.onChange((0, _strings.isEmptyString)(value));
    },
    // In Preact, when used in addition to onInput, the onChange follows the standard DOM change event
    // and gets fired only when an element's value is committed by the user.
    // @see https://preactjs.com/guide/v10/differences-to-react/#use-oninput-instead-of-onchange
    onChange: function onChange(_ref3) {
      var value = _ref3.currentTarget.value;
      var currentValue = explicitValue !== null && explicitValue !== void 0 ? explicitValue : '';
      if (value !== currentValue) _onChange === null || _onChange === void 0 ? void 0 : _onChange(value);
    },
    onFocus: function onFocus() {
      _onFocus === null || _onFocus === void 0 ? void 0 : _onFocus();
      labelled.onFocus();
    },
    onKeyDown: onKeyDown,
    ref: refsSetter,
    role: role,
    value: localValue,
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete),
    autofocus: autofocus
  });

  return field;
});
exports.Field = Field;

function usePartiallyControlledState(value) {
  var _useState = (0, _react.useState)(value),
      _useState2 = _slicedToArray(_useState, 2),
      localValue = _useState2[0],
      setLocalValue = _useState2[1];

  var lastExplicitValue = (0, _react.useRef)(value);
  var valueToReturn = localValue;

  if (lastExplicitValue.current !== value) {
    lastExplicitValue.current = value;
    setLocalValue(value);
    valueToReturn = value;
  }

  return [valueToReturn, setLocalValue];
} // Takes the `type` we allow for a TextField props, and maps it to the
// valid type for an HTML input. Currently, the only difference is
// that we use the full word `telephone` instead of `tel`.


function normalizeType(type) {
  return type === 'telephone' ? 'tel' : type;
}