"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.themeWithKnobs = themeWithKnobs;

var _react = _interopRequireDefault(require("react"));

var _addonKnobs = require("@storybook/addon-knobs");

var _hsluv = require("hsluv");

var _ = require("..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var Group;

(function (Group) {
  Group["TextField"] = "Text field";
  Group["Select"] = "Select";
  Group["Breadcrumb"] = "Breadcrumb";
  Group["Actions"] = "Actions";
  Group["HeadingLevel1"] = "Heading level 1";
  Group["HeadingLevel2"] = "Heading level 2";
  Group["HeadingLevel3"] = "Heading level 3";
  Group["Checkbox"] = "Checkbox";
  Group["PrimaryButton"] = "Primary button";
  Group["SecondaryButton"] = "Secondary button";
  Group["FormLayout"] = "Form layout";
  Group["Tag"] = "Tag";
  Group["Tooltip"] = "Tooltip";
  Group["Banner"] = "Banner";
  Group["OptionList"] = "Option list";
  Group["Style"] = "Style";
  Group["Color"] = "Color";
  Group["Typography"] = "Typography";
})(Group || (Group = {}));

var Label;

(function (Label) {
  Label["Border"] = "Border";
  Label["BorderRadius"] = "Border radius";
  Label["LabelPosition"] = "Label position";
  Label["Style"] = "Style";
  Label["ErrorIndentation"] = "Error indentation";
  Label["BlockPadding"] = "Block padding";
  Label["InlinePadding"] = "Inline padding";
  Label["LoadingStyle"] = "Loading style";
})(Label || (Label = {}));

var Action;

(function (Action) {
  Action["Display"] = "Display";
})(Action || (Action = {}));

var Breadcrumb;

(function (Breadcrumb) {
  Breadcrumb["Gap"] = "Gap";
  Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
  Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));

var SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
var BORDER_RADIUS_OPTIONS = optionify(['none', 'tight', 'base', 'fullyRounded']);
var SIMPLE_BORDER_OPTIONS = optionify(['full', 'none']);
var BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
var LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
var ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
var BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
var NUMBER_STYLE_OPTIONS = optionify(['none', 'decimal', 'decimalLeadingZero']);
var STYLE_OPTIONS = optionify(['style1']);
var SIZE_OPTIONS = optionify(['base', 'xsmall', 'small', 'medium', 'large', 'xlarge', 'xxlarge']);
var LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
var FONT_OPTIONS = optionify(['primary', 'secondary']);
var WEIGHT_OPTIONS = optionify(['base', 'bold']);
var LINE_SIZE_OPTIONS = optionify(['base', 'large']);
var KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);
var SPACING_OPTIONS = optionify(['none', 'tight4x', 'tight3x', 'tight2x', 'tight1x', 'tight', 'base', 'loose', 'loose1x', 'loose2x', 'loose3x', 'loose4x']);
var SIMPLE_SPACING_OPTIONS = optionify(['tight', 'base']);
var LOADING_STYLE_OPTIONS = optionify(['spinner', 'progressBar']);
var ERROR_INDENTATION_OPTIONS = optionify(['none', 'toText']);
var OPACITY_OPTIONS = optionify(['translucent', 'opaque']);
var TEXT_ALIGNMENT_OPTIONS = optionify(['start', 'center']);
var OPTION_LIST_BORDER_OPTIONS = optionify(['full', 'none', 'inner']);
var BORDER_STYLE_OPTIONS = optionify(['base', 'dotted']);
var UNDEFINED = '';
var FONT_WEIGHT_OPTIONS = optionify(['100', '200', '300', '400', '500', '600', '700', '800', '900']);

function themeWithKnobs() {
  for (var _len = arguments.length, picks = new Array(_len), _key = 0; _key < _len; _key++) {
    picks[_key] = arguments[_key];
  }

  return function (storyFn) {
    return /*#__PURE__*/_react["default"].createElement(ThemeWithKnobs, {
      pick: picks
    }, storyFn());
  };
}

function ThemeWithKnobs(_ref) {
  var _ref$pick = _ref.pick,
      pick = _ref$pick === void 0 ? [] : _ref$pick,
      children = _ref.children;
  var textFields = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined
  };
  var selects = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined
  };
  var actions = {
    display: undefined
  };
  var buyerJourney = {
    gap: undefined,
    chevronIconSeparator: true,
    numberStyle: undefined,
    typographyStyle: undefined
  };
  var headingLevel1 = {
    typographyStyle: undefined
  };
  var headingLevel2 = {
    typographyStyle: undefined
  };
  var headingLevel3 = {
    typographyStyle: undefined
  };
  var checkbox = {
    borderRadius: undefined,
    errorIndentation: undefined
  };
  var primaryButton = {
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  var secondaryButton = {
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  var formLayout = {
    spacing: undefined
  };
  var tag = {
    borderRadius: undefined
  };
  var tooltip = {
    borderRadius: undefined,
    opacity: undefined,
    textAlignment: undefined
  };
  var banner = {
    border: undefined,
    borderRadius: undefined
  };
  var optionList = {
    border: undefined,
    borderRadius: undefined,
    borderStyle: undefined,
    gap: undefined,
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined
  };

  if (pick.includes('textFields')) {
    textFields.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, textFields.border, Group.TextField);
    textFields.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFields.labelPosition, Group.TextField);
    textFields.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, textFields.errorIndentation, Group.TextField);
  }

  if (pick.includes('select')) {
    selects.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, selects.border, Group.Select);
    selects.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, selects.labelPosition, Group.Select);
    selects.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, selects.errorIndentation, Group.Select);
  }

  if (pick.includes('actions')) {
    actions.display = (0, _addonKnobs.select)(Action.Display, ACTIONS_DISPLAY_OPTIONS, actions.display, Group.Actions);
  }

  if (pick.includes('buyerJourney')) {
    buyerJourney.gap = (0, _addonKnobs.select)(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, buyerJourney.gap, Group.Breadcrumb);
    buyerJourney.chevronIconSeparator = (0, _addonKnobs["boolean"])(Breadcrumb.ChevronIconSeparator, buyerJourney.chevronIconSeparator, Group.Breadcrumb);
    buyerJourney.numberStyle = (0, _addonKnobs.select)(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, buyerJourney.numberStyle, Group.Breadcrumb);
    buyerJourney.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, buyerJourney.typographyStyle, Group.Breadcrumb);
  }

  if (pick.includes('checkbox')) {
    checkbox.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, SIMPLE_BORDER_RADIUS_OPTIONS, checkbox.borderRadius, Group.Checkbox);
    checkbox.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, checkbox.errorIndentation, Group.Checkbox);
  }

  if (pick.includes('banner')) {
    banner.border = (0, _addonKnobs.select)(Label.Border, SIMPLE_BORDER_OPTIONS, banner.border, Group.Banner);
    banner.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, banner.borderRadius, Group.Banner);
  }

  if (pick.includes('optionList')) {
    optionList.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, optionList.borderRadius, Group.OptionList);
    optionList.border = (0, _addonKnobs.select)(Label.Border, OPTION_LIST_BORDER_OPTIONS, optionList.border, Group.OptionList);
    optionList.borderStyle = (0, _addonKnobs.select)('Border style', BORDER_STYLE_OPTIONS, optionList.borderStyle, Group.OptionList);
    optionList.gap = (0, _addonKnobs.select)('Gap', optionify(['none', 'tight', 'base']), optionList.gap, Group.OptionList);
    optionList.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, optionList.blockPadding, Group.OptionList);
    optionList.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, optionList.inlinePadding, Group.OptionList);
    optionList.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, optionList.typographyStyle, Group.OptionList);
  }

  if (pick.includes('headingLevel1')) {
    headingLevel1.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel1.typographyStyle, Group.HeadingLevel1);
  }

  if (pick.includes('headingLevel2')) {
    headingLevel2.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel2.typographyStyle, Group.HeadingLevel2);
  }

  if (pick.includes('headingLevel3')) {
    headingLevel3.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel3.typographyStyle, Group.HeadingLevel3);
  }

  if (pick.includes('primaryButton')) {
    primaryButton.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, primaryButton.typographyStyle, Group.PrimaryButton);
    primaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, primaryButton.blockPadding, Group.PrimaryButton);
    primaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, primaryButton.inlinePadding, Group.PrimaryButton);
    primaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, primaryButton.loadingStyle, Group.PrimaryButton);
  }

  if (pick.includes('secondaryButton')) {
    secondaryButton.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, secondaryButton.typographyStyle, Group.SecondaryButton);
    secondaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, secondaryButton.blockPadding, Group.SecondaryButton);
    secondaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, secondaryButton.inlinePadding, Group.SecondaryButton);
    secondaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, secondaryButton.loadingStyle, Group.SecondaryButton);
  }

  if (pick.includes('formLayout')) {
    formLayout.spacing = (0, _addonKnobs.select)('Spacing', SIMPLE_SPACING_OPTIONS, formLayout.spacing, Group.FormLayout);
  }

  if (pick.includes('tag')) {
    tag.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tag.borderRadius, Group.Tag);
  }

  if (pick.includes('tooltip')) {
    tooltip.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tooltip.borderRadius, Group.Tooltip);
    tooltip.opacity = (0, _addonKnobs.select)('Opacity', OPACITY_OPTIONS, tooltip.opacity, Group.Tooltip);
    tooltip.textAlignment = (0, _addonKnobs.select)('Text alignment', TEXT_ALIGNMENT_OPTIONS, tooltip.textAlignment, Group.Tooltip);
  }

  var theme = (0, _.createTheme)({
    textFields: textFields,
    select: selects,
    actions: actions,
    buyerJourney: buyerJourney,
    headingLevel1: headingLevel1,
    headingLevel2: headingLevel2,
    headingLevel3: headingLevel3,
    checkbox: checkbox,
    primaryButton: primaryButton,
    secondaryButton: secondaryButton,
    formLayout: formLayout,
    tag: tag,
    tooltip: tooltip,
    banner: banner,
    optionList: optionList,
    typographyStyle1: {
      size: (0, _addonKnobs.select)("Size", SIZE_OPTIONS, undefined, Group.Style),
      letterCase: (0, _addonKnobs.select)("Letter case", LETTER_CASE_OPTIONS, undefined, Group.Style),
      fonts: (0, _addonKnobs.select)("Font", FONT_OPTIONS, undefined, Group.Style),
      weight: (0, _addonKnobs.select)("Weight", WEIGHT_OPTIONS, undefined, Group.Style),
      lineSize: (0, _addonKnobs.select)("Line size", LINE_SIZE_OPTIONS, undefined, Group.Style),
      kerning: (0, _addonKnobs.select)("Kerning", KERNING_OPTIONS, undefined, Group.Style)
    },
    typographyScale: {
      base: (0, _addonKnobs.number)('Base size', 14, {}, Group.Typography),
      ratio: (0, _addonKnobs.number)('Scale ratio', 1.285, {
        step: 0.001
      }, Group.Typography)
    },
    typographyPrimary: {
      fonts: (0, _addonKnobs.text)('Primary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Primary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Primary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    typographySecondary: {
      fonts: (0, _addonKnobs.text)('Secondary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Secondary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Secondary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    colors: {
      canvas: hsluvColorPair('Canvas'),
      surfacePrimary: hsluvColorPair('Surface primary'),
      surfaceSecondary: hsluvColorPair('Surface secondary'),
      surfaceTertiary: hsluvColorPair('Surface tertiary'),
      surfaceQuaternary: hsluvColorPair('Surface quaternary'),
      primary: hsluvColorPair('Primary'),
      secondary: hsluvColorPair('Secondary'),
      tertiary: hsluvColorPair('Tertiary'),
      interactive: hsluvColorPair('Interactive'),
      success: hsluvColorPair('Success'),
      critical: hsluvColorPair('Critical')
    }
  });
  return /*#__PURE__*/_react["default"].createElement(_.Theme, {
    theme: theme
  }, children);
}

function optionify(array) {
  return array.reduce(function (acc, value) {
    return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, value, value));
  }, {
    ' ': undefined
  });
}

function toHsluv(str) {
  if (str === UNDEFINED) return undefined;
  var rgb = str.slice(5, -1).split(',').slice(0, 3).map(Number).map(function (num) {
    return num / 255;
  });
  return (0, _hsluv.rgbToHsluv)(rgb);
}

function hsluvColor(name) {
  return toHsluv((0, _addonKnobs.color)(name, UNDEFINED, Group.Color));
}

function hsluvColorPair(name) {
  return {
    background: hsluvColor("".concat(name, " background")),
    foreground: hsluvColor("".concat(name, " foreground"))
  };
}