import React from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { useTranslate } from '../AppContext';
import { useTransition } from '../../utilities/transition';
import { Spinner } from '../Spinner';
import { UnstyledLink } from '../Link';
import { button as legacyButtonClassName } from '../../utilities/legacy';
import { usePrefersReducedMotion } from '../../utilities/media-query';
import { useConnected } from '../Connected';
import { useThemeConfiguration } from '../Theme';
import typographyStyles from '../../utilities/typography-styles.css';
import styles from './Button.css';
export function Button(_ref) {
  var children = _ref.children,
      _ref$submit = _ref.submit,
      submit = _ref$submit === void 0 ? false : _ref$submit,
      disabled = _ref.disabled,
      onPress = _ref.onPress,
      to = _ref.to,
      subdued = _ref.subdued,
      plain = _ref.plain,
      secondary = _ref.secondary,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? false : _ref$loading,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? false : _ref$fill,
      loadingLabel = _ref.loadingLabel,
      underline = _ref.underline;
  var href = disabled ? undefined : to;
  var onClick = disabled ? undefined : function () {
    return onPress === null || onPress === void 0 ? void 0 : onPress();
  };
  var translate = useTranslate();
  var prefersReducedMotion = usePrefersReducedMotion();
  var transition = useTransition(loading, {
    enter: 'slow'
  });
  var connected = useConnected();

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.primaryButton,
      primaryStyle = _useThemeConfiguratio2.typographyStyle,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.loadingStyle,
      primaryLoading = _useThemeConfiguratio3 === void 0 ? 'spinner' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio.secondaryButton,
      secondaryStyle = _useThemeConfiguratio4.typographyStyle,
      _useThemeConfiguratio5 = _useThemeConfiguratio4.loadingStyle,
      secondaryLoading = _useThemeConfiguratio5 === void 0 ? 'spinner' : _useThemeConfiguratio5;

  var loadingStyle = secondary ? secondaryLoading : primaryLoading;
  var classes = classNames(styles.Button, legacyButtonClassName, subdued && styles.isSubdued, plain && styles.isPlain, plain && underline && styles.isUnderline, disabled && styles.isDisabled, loading && loadingStyle === 'spinner' && styles.isLoading, fill && styles.isFill, loading && loadingStyle === 'spinner' && styles[variationName('isLoading-transition', transition)], connected && styles.isConnected, secondary && styles.isSecondary, loading && loadingStyle === 'progressBar' && styles[loadingStyle]);
  var normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  var contentTypography = secondary ? secondaryStyle && typographyStyles[secondaryStyle] : primaryStyle && typographyStyles[primaryStyle];
  var content = /*#__PURE__*/React.createElement("span", {
    className: classNames(styles.Content, contentTypography)
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);
  var type = submit ? 'submit' : 'button';
  var loadingMarkup = /*#__PURE__*/React.createElement("span", {
    className: classNames(styles.LoadingContent, !prefersReducedMotion && styles.Spinner)
  }, /*#__PURE__*/React.createElement(Spinner, {
    size: "small",
    color: "inherit"
  }, normalizedLoadingLabel));

  if (href) {
    return /*#__PURE__*/React.createElement(UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress
    }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
  }

  return /*#__PURE__*/React.createElement("button", {
    type: type,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading
  }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
}