function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { Icon } from '../Icon';
import { VisuallyHidden } from '../VisuallyHidden';
import { HiddenForAccessibility } from '../HiddenForAccessibility';
import { InlineError } from '../InlineError';
import { useThemeConfiguration } from '../Theme';
import { useId, createIdCreator } from '../../utilities/id';
import { errorId } from '../../utilities/errors';
import typographyStyles from '../../utilities/typography-styles.css';
import styles from './Checkbox.css';
var createId = createIdCreator('Checkbox');
export function Checkbox(_ref) {
  var explicitId = _ref.id,
      accessibilityLabel = _ref.accessibilityLabel,
      error = _ref.error,
      disabled = _ref.disabled,
      children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["id", "accessibilityLabel", "error", "disabled", "children"]);

  var id = useId(explicitId, createId);

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.checkbox,
      errorIndentation = _useThemeConfiguratio2.errorIndentation,
      errorTypographyStyle = _useThemeConfiguratio2.errorTypographyStyle;

  var errorMarkup = error ? /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.Error, errorTypographyStyle && typographyStyles[errorTypographyStyle])
  }, /*#__PURE__*/React.createElement(InlineError, {
    controlID: id
  }, error)) : null;
  var labelClassName = classNames(styles.Label, disabled && styles['Label-isDisabled']);
  var hasError = Boolean(error);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.Wrapper, hasError && styles.hasError, hasError && errorIndentation && styles[variationName('errorIndentation', errorIndentation)])
  }, /*#__PURE__*/React.createElement(CheckboxControl, Object.assign({
    id: id,
    name: name,
    error: Boolean(error),
    disabled: disabled
  }, rest)), /*#__PURE__*/React.createElement("label", {
    htmlFor: id,
    className: labelClassName
  }, accessibilityLabel ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(VisuallyHidden, null, accessibilityLabel), /*#__PURE__*/React.createElement(HiddenForAccessibility, null, children)) : children), errorMarkup);
}
export function CheckboxControl(_ref2) {
  var id = _ref2.id,
      name = _ref2.name,
      _ref2$value = _ref2.value,
      value = _ref2$value === void 0 ? false : _ref2$value,
      _ref2$checked = _ref2.checked,
      checked = _ref2$checked === void 0 ? value : _ref2$checked,
      disabled = _ref2.disabled,
      _ref2$error = _ref2.error,
      error = _ref2$error === void 0 ? false : _ref2$error,
      _onChange = _ref2.onChange;

  var _useThemeConfiguratio3 = useThemeConfiguration(),
      _useThemeConfiguratio4 = _useThemeConfiguratio3.checkbox,
      _useThemeConfiguratio5 = _useThemeConfiguratio4.background,
      background = _useThemeConfiguratio5 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio5,
      _useThemeConfiguratio6 = _useThemeConfiguratio4.borderColor,
      borderColor = _useThemeConfiguratio6 === void 0 ? 'base' : _useThemeConfiguratio6;

  var className = classNames(styles.Input, error && styles['Input-hasError'], disabled && styles['Input-isDisabled'], styles[variationName('Input-background', background)], styles[variationName('Input-borderColor', borderColor)]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Checkbox
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: function onChange(_ref3) {
      var currentTarget = _ref3.currentTarget;
      _onChange === null || _onChange === void 0 ? void 0 : _onChange(currentTarget.checked);
    },
    className: className,
    "aria-describedby": error ? errorId(id) : undefined,
    "aria-invalid": error
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.Icon
  }, /*#__PURE__*/React.createElement(Icon, {
    source: "checkmark",
    size: "small"
  })));
}