import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import faker from 'faker';
import { Thumbnail } from '.';
var defaultProps = {
  source: faker.internet.url(),
  description: faker.lorem.words(2)
};
describe('Thumbnail', function () {
  it('renders an <img /> with an src and an alt attributes', function () {
    var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
      badge: "1"
    })));
    expect(thumbnail).toContainReactComponent('img', {
      src: defaultProps.source,
      alt: defaultProps.description
    });
  });
  describe('sources prop', function () {
    it('does not render srcset if sources are undefined', function () {
      var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, defaultProps));
      expect(thumbnail).not.toContainReactComponent('img', {
        srcSet: expect.anything()
      });
    });
    it('renders a srcset when provided with sources', function () {
      var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
        sources: ['a 1x', 'b 2x', 'c 3x']
      })));
      expect(thumbnail).toContainReactComponent('img', {
        srcSet: 'a 1x, b 2x, c 3x'
      });
    });
  });
  it('renders a badge when provided as a string', function () {
    var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
      badge: "1"
    })));
    expect(thumbnail.find('span')).toContainReactText('1');
  });
  it('renders a badge when provided as a number', function () {
    var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
      badge: 0
    })));
    expect(thumbnail.find('span')).toContainReactText('0');
  });
  it("doesn't render a badge when not provided", function () {
    var thumbnail = mount( /*#__PURE__*/React.createElement(Thumbnail, defaultProps));
    expect(thumbnail).not.toContainReactComponent('span');
  });
});