function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useRef, useState } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { createIdCreator, useId } from '../../utilities/id';
import { useTransition } from '../../utilities/transition';
import { Popper, usePopper } from '../Popper';
import { TextBlock } from '../TextBlock';
import { TextContainer } from '../TextContainer';
import { useThemeConfiguration } from '../Theme';
import styles from './Tooltip.css';
var createId = createIdCreator('Tooltip');
export function Tooltip(_ref) {
  var content = _ref.content,
      children = _ref.children;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      active = _useState2[0],
      setActive = _useState2[1];

  var buttonRef = useRef(null);
  var ignoreNonTouchEvents = useRef(false);
  var transition = useTransition(active, {
    exit: 'base'
  });

  function handleKeyDown(event) {
    switch (event.key) {
      case 'Enter':
      case 'Space':
        event.preventDefault();
        setActive(!active);
        break;

      case 'Escape':
      case 'Esc':
        event.preventDefault();
        setActive(false);
        break;
    }
  }

  var id = useId(undefined, createId);
  var controlId = active ? id : undefined;
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: styles.Button,
    "aria-pressed": active,
    "aria-controls": controlId,
    "aria-describedby": controlId,
    onFocus: function onFocus() {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onBlur: function onBlur() {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(false);
    },
    onMouseEnter: function onMouseEnter() {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onMouseLeave: function onMouseLeave() {
      setActive(false);
    },
    onTouchStart: function onTouchStart() {
      ignoreNonTouchEvents.current = true;
    },
    onClick: function onClick() {
      setActive(!active);
    },
    onKeyDown: handleKeyDown,
    ref: buttonRef
  }, children), transition !== 'exited' && /*#__PURE__*/React.createElement(Popper, {
    activator: buttonRef.current,
    preventOverflow: true
  }, /*#__PURE__*/React.createElement(TooltipContent, {
    content: content,
    id: controlId,
    onMouseEnter: function onMouseEnter() {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onMouseLeave: function onMouseLeave() {
      setActive(false);
    },
    transition: transition
  })));
}
export function TooltipContent(_ref2) {
  var content = _ref2.content,
      id = _ref2.id,
      onMouseEnter = _ref2.onMouseEnter,
      onMouseLeave = _ref2.onMouseLeave,
      transition = _ref2.transition;

  var _usePopper = usePopper(),
      clipping = _usePopper.clipping,
      spacing = _usePopper.spacing;

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.tooltip,
      background = _useThemeConfiguratio2.background,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.opacity,
      opacity = _useThemeConfiguratio3 === void 0 ? 'translucent' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.borderRadius,
      borderRadius = _useThemeConfiguratio4 === void 0 ? 'base' : _useThemeConfiguratio4,
      _useThemeConfiguratio5 = _useThemeConfiguratio2.textAlignment,
      textAlignment = _useThemeConfiguratio5 === void 0 ? 'center' : _useThemeConfiguratio5;

  var offsetX = (clipping.right || clipping.left) && "calc(50% - ".concat((clipping.right || clipping.left) + spacing, "px)");
  var className = classNames(styles.Tooltip, styles[variationName('transition', transition)], styles[variationName('Tooltip-opacity', opacity)], styles[variationName('Tooltip-borderRadius', borderRadius)], background && styles[variationName('Tooltip-background', background)]);
  var alignment = textAlignment === 'start' ? 'leading' : textAlignment;
  return (
    /*#__PURE__*/

    /* eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions */
    React.createElement("div", {
      id: id,
      role: "tooltip",
      onMouseEnter: onMouseEnter,
      onMouseLeave: onMouseLeave,
      className: className,
      style: _objectSpread({}, offsetX && {
        transformOrigin: "".concat(offsetX, " 120%")
      })
    }, /*#__PURE__*/React.createElement(TextContainer, {
      alignment: alignment
    }, /*#__PURE__*/React.createElement(TextBlock, {
      size: "small"
    }, content)), /*#__PURE__*/React.createElement(TooltipArrow, null))
  );
}
export function TooltipArrow() {
  var _usePopper2 = usePopper(),
      clipping = _usePopper2.clipping,
      spacing = _usePopper2.spacing;

  var offsetX = (clipping.right || clipping.left) && "calc(".concat(document.dir === 'ltr' ? '-50' : '50', "% - ").concat((clipping.right || clipping.left) + spacing, "px)");
  var transform = (window.devicePixelRatio || 1) < 2 ? "translate(".concat(offsetX, ", 0)") : "translate3d(".concat(offsetX, ", 0, 0)");
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Arrow,
    style: _objectSpread({}, offsetX && {
      transform: transform,
      MozTransform: transform,
      webkitTransform: transform
    })
  });
}