"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = Button;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _AppContext = require("../AppContext");

var _transition = require("../../utilities/transition");

var _Spinner = require("../Spinner");

var _Link = require("../Link");

var _legacy = require("../../utilities/legacy");

var _mediaQuery = require("../../utilities/media-query");

var _Connected = require("../Connected");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Button = _interopRequireDefault(require("./Button.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Button({
  children,
  submit = false,
  disabled,
  onPress,
  to,
  subdued,
  plain,
  secondary,
  loading = false,
  fill = false,
  loadingLabel,
  underline
}) {
  const href = disabled ? undefined : to;
  const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
  const translate = (0, _AppContext.useTranslate)();
  const prefersReducedMotion = (0, _mediaQuery.usePrefersReducedMotion)();
  const transition = (0, _transition.useTransition)(loading, {
    enter: 'slow'
  });
  const connected = (0, _Connected.useConnected)();
  const {
    primaryButton: {
      typographyStyle: primaryStyle,
      loadingStyle: primaryLoading = 'spinner'
    },
    secondaryButton: {
      typographyStyle: secondaryStyle,
      loadingStyle: secondaryLoading = 'spinner'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const loadingStyle = secondary ? secondaryLoading : primaryLoading;
  const classes = (0, _cssUtilities.classNames)(_Button.default.Button, _legacy.button, subdued && _Button.default.isSubdued, plain && _Button.default.isPlain, plain && underline && _Button.default.isUnderline, disabled && _Button.default.isDisabled, loading && loadingStyle === 'spinner' && _Button.default.isLoading, fill && _Button.default.isFill, loading && loadingStyle === 'spinner' && _Button.default[(0, _cssUtilities.variationName)('isLoading-transition', transition)], connected && _Button.default.isConnected, secondary && _Button.default.isSecondary, loading && loadingStyle === 'progressBar' && _Button.default[loadingStyle]);
  const normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  const contentTypography = secondary ? secondaryStyle && _typographyStyles.default[secondaryStyle] : primaryStyle && _typographyStyles.default[primaryStyle];

  const content = /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button.default.Content, contentTypography)
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);

  const type = submit ? 'submit' : 'button';

  const loadingMarkup = /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button.default.LoadingContent, !prefersReducedMotion && _Button.default.Spinner)
  }, /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
    size: "small",
    color: "inherit"
  }, normalizedLoadingLabel));

  if (href) {
    return /*#__PURE__*/_react.default.createElement(_Link.UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress
    }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
  }

  return /*#__PURE__*/_react.default.createElement("button", {
    type: type,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading
  }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
}