"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Radio = Radio;
exports.RadioControl = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _VisuallyHidden = require("../VisuallyHidden");

var _Theme = require("../Theme");

var _id = require("../../utilities/id");

var _Radio = _interopRequireDefault(require("./Radio.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createId = (0, _id.createIdCreator)('Radio');

function Radio({
  id: explicitId,
  accessibilityLabel,
  children,
  disabled,
  ...rest
}) {
  const id = (0, _id.useId)(explicitId, createId);
  const className = (0, _cssUtilities.classNames)(_Radio.default.Label, disabled && _Radio.default['Label-isDisabled']);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Radio.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement(RadioControl, Object.assign({
    id: id,
    disabled: disabled
  }, rest)), /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: id,
    className: className
  }, accessibilityLabel ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, accessibilityLabel), /*#__PURE__*/_react.default.createElement(_HiddenForAccessibility.HiddenForAccessibility, null, children)) : children));
}

const RadioControl = ({
  id,
  name,
  value = false,
  checked = value,
  disabled,
  onChange
}) => {
  const {
    radio: {
      background = 'surfaceTertiary',
      borderColor = 'base'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_Radio.default.Input, disabled && _Radio.default['Input-isDisabled'], _Radio.default[(0, _cssUtilities.variationName)('Input-background', background)], _Radio.default[(0, _cssUtilities.variationName)('Input-borderColor', borderColor)]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Radio.default.Radio
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "radio",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: ({
      currentTarget
    }) => {
      onChange === null || onChange === void 0 ? void 0 : onChange(currentTarget.checked);
    },
    className: className
  }));
};

exports.RadioControl = RadioControl;