"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StepperStep = StepperStep;
exports.StepperStepIcon = StepperStepIcon;
exports.StepperStepLabel = StepperStepLabel;
exports.StepperStepConnector = StepperStepConnector;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../../../Icon");

var _TextBlock = require("../../../TextBlock");

var _VisuallyHidden = require("../../../VisuallyHidden");

var _hooks = require("../../hooks");

var _StepperStep = _interopRequireDefault(require("./StepperStep.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function StepperStep({
  children,
  description,
  icon,
  iconColor,
  id,
  label,
  state,
  stateHidden = true
}) {
  const {
    steps
  } = (0, _hooks.useStepper)();
  const first = Object.keys(steps).indexOf(id) === 0;
  const {
    [id]: {
      active,
      completed
    }
  } = steps;
  const className = (0, _cssUtilities.classNames)(_StepperStep.default.StepperStep, completed && _StepperStep.default.Completed);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !first && /*#__PURE__*/_react.default.createElement(StepperStepConnector, {
    active: active,
    completed: completed
  }), /*#__PURE__*/_react.default.createElement("li", {
    className: className,
    "aria-current": active
  }, /*#__PURE__*/_react.default.createElement(StepperStepIcon, {
    active: active,
    completed: completed,
    source: icon,
    color: iconColor
  }), /*#__PURE__*/_react.default.createElement(StepperStepLabel, {
    active: active,
    completed: completed,
    description: description,
    label: label,
    state: state,
    stateHidden: stateHidden
  }), children));
}

function StepperStepIcon({
  active,
  color = 'interactive',
  source,
  completed
}) {
  const className = (0, _cssUtilities.classNames)(_StepperStep.default.StepperStepIcon, active && _StepperStep.default.active, completed && _StepperStep.default.completed);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: source,
    color: active || completed ? color : 'subdued',
    size: "large"
  }));
}

function StepperStepLabel({
  active,
  completed,
  description,
  label,
  state,
  stateHidden
}) {
  const className = (0, _cssUtilities.classNames)(_StepperStep.default.StepperStepLabel, (active || completed) && _StepperStep.default.completed);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, stateHidden ? /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, state) : /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, null, state), /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, {
    emphasized: active || completed
  }, label)), (active || completed) && description && /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, {
    size: "small",
    subdued: true
  }, description));
}

function StepperStepConnector({
  active,
  completed
}) {
  const className = (0, _cssUtilities.classNames)(_StepperStep.default.StepperStepConnector, (active || completed) && _StepperStep.default.completed);
  return /*#__PURE__*/_react.default.createElement("li", {
    className: className,
    "aria-hidden": true
  });
}