"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createTheme = createTheme;
exports.colorSubdued = colorSubdued;
exports.colorTextEmphasized = colorTextEmphasized;
exports.colorTextSubdued = colorTextSubdued;
exports.colorBorderEmphasized = colorBorderEmphasized;
exports.UiTheme = exports.ThemeContext = void 0;

var _react = require("react");

var _hsluv = require("../../utilities/hsluv");

var _modularScale = require("./utilities/modularScale");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const ThemeContext = /*#__PURE__*/(0, _react.createContext)(undefined);
exports.ThemeContext = ThemeContext;

function createTheme({
  global = {},
  buyerJourney = {},
  typographyScale = {},
  typographyPrimary = {},
  typographySecondary = {},
  headingLevel1 = {},
  headingLevel2 = {},
  headingLevel3 = {},
  controls = {},
  label = {},
  textFields = {},
  select = {},
  checkbox = {},
  radio = {},
  optionList = {},
  reviewBlock = {},
  actions = {},
  lineItems = {},
  moneyLines = {},
  moneySummary = {},
  primaryButton = {},
  secondaryButton = {},
  formLayout = {},
  tag = {},
  tooltip = {},
  banner = {},
  typographyStyle1 = {},
  typographyStyle2 = {},
  typographyStyle3 = {},
  typographyStyle4 = {},
  typographyStyle5 = {},
  typographyStyle6 = {},
  typographyStyle7 = {},
  typographyStyle8 = {},
  typographyStyle9 = {},
  colors
} = {}) {
  return new UiTheme({
    global,
    buyerJourney,
    typographyScale,
    typographyPrimary,
    typographySecondary,
    headingLevel1,
    headingLevel2,
    headingLevel3,
    controls,
    label,
    textFields,
    select,
    checkbox,
    radio,
    optionList,
    reviewBlock,
    actions,
    lineItems,
    moneyLines,
    moneySummary,
    primaryButton,
    secondaryButton,
    formLayout,
    tag,
    tooltip,
    banner,
    typographyStyle1,
    typographyStyle2,
    typographyStyle3,
    typographyStyle4,
    typographyStyle5,
    typographyStyle6,
    typographyStyle7,
    typographyStyle8,
    typographyStyle9,
    colors
  });
}
/**
 * This scaling factor represents the ratio of the height of the ratio to the base font-size of the document.
 * E.g., a font-size of 14px means that the radio element will have width & height of 18px
 */


const RADIO_SCALE = 1.2857142857142858;
const CHECKBOX_SCALE = 1.2857142857142858;

class UiTheme {
  constructor(configuration) {
    var _configuration$colors, _configuration$typogr;

    _defineProperty(this, "configuration", void 0);

    _defineProperty(this, "customProperties", void 0);

    _defineProperty(this, "listeners", {
      change: new Set(),
      preview: new Set()
    });

    this.configuration = { ...configuration,
      colors: colorsFromOverrides((_configuration$colors = configuration.colors) !== null && _configuration$colors !== void 0 ? _configuration$colors : {}),
      typographyScale: (_configuration$typogr = configuration.typographyScale) !== null && _configuration$typogr !== void 0 ? _configuration$typogr : {}
    };
    this.customProperties = customPropertiesFromThemeConfiguration(this.configuration);
  }

  preview(colors, typographyScale) {
    const colorsCustomProperties = customPropertiesFromRoleColors(colorsFromOverrides(colors));
    const typographyScaleCustomProperties = customPropertiesFromTypographyScale(typographyScale);

    for (const listener of this.listeners.preview) {
      listener({ ...colorsCustomProperties,
        ...typographyScaleCustomProperties
      });
    }
  }

  set(key, value) {
    this.configuration = { ...this.configuration,
      [key]: value
    };

    for (const listener of this.listeners.change) {
      listener(this.configuration);
    }

    const customProperties = customPropertiesFromThemeConfiguration(this.configuration);

    for (const listener of this.listeners.preview) {
      listener(customProperties);
    }
  }

  on(event, listener) {
    this.listeners[event].add(listener);
    return () => {
      this.listeners[event].delete(listener);
    };
  }

}

exports.UiTheme = UiTheme;

function colorSubdued(colorPair) {
  var _colorPair$background;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background = colorPair.background) === null || _colorPair$background === void 0 ? void 0 : _colorPair$background.adjust({
    l: l => l > 50 ? l - 1.7 : Math.max(l - 5.2, 0)
  });
}

function colorTextEmphasized(colorPair) {
  var _colorPair$foreground, _colorPair$background2;

  return (colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) ? colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$foreground = colorPair.foreground) === null || _colorPair$foreground === void 0 ? void 0 : _colorPair$foreground.adjust({
    l: l => l > 50 ? Math.min(l + 15, 100) : l - 10
  }) : colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background2 = colorPair.background) === null || _colorPair$background2 === void 0 ? void 0 : _colorPair$background2.adjust({
    s: s => s > 50 ? s : Math.min(s + 15, 100),
    l: l => l > 50 ? Math.max(l - 77.5, 0) : 98.3
  });
}

function colorTextSubdued(colorPair) {
  var _colorPair$foreground2, _colorPair$background3;

  return (colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) ? colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$foreground2 = colorPair.foreground) === null || _colorPair$foreground2 === void 0 ? void 0 : _colorPair$foreground2.adjust({
    l: l => l > 50 ? Math.max(l - 35, 0) : l - 15
  }) : colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background3 = colorPair.background) === null || _colorPair$background3 === void 0 ? void 0 : _colorPair$background3.adjust({
    s: s => s > 50 ? Math.max(s - 55, 0) : s,
    l: l => l > 50 ? Math.max(l - 49.9, 10) : Math.min(l + 63.2, 90)
  });
}

function colorHovered(colorPair) {
  var _colorPair$background4;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background4 = colorPair.background) === null || _colorPair$background4 === void 0 ? void 0 : _colorPair$background4.adjust({
    l: l => l - 10
  });
}

function colorPressed(colorPair) {
  var _colorPair$background5;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background5 = colorPair.background) === null || _colorPair$background5 === void 0 ? void 0 : _colorPair$background5.adjust({
    l: l => l - 10
  });
}

function colorText(colorPair) {
  var _colorPair$foreground3, _colorPair$background6;

  return (_colorPair$foreground3 = colorPair === null || colorPair === void 0 ? void 0 : colorPair.foreground) !== null && _colorPair$foreground3 !== void 0 ? _colorPair$foreground3 : colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background6 = colorPair.background) === null || _colorPair$background6 === void 0 ? void 0 : _colorPair$background6.adjust({
    l: l => l > 50 ? 4 : 96
  });
}

function colorTextHovered(colorPair) {
  var _colorPair$background7;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background7 = colorPair.background) === null || _colorPair$background7 === void 0 ? void 0 : _colorPair$background7.adjust({
    l: l => l - 10
  });
}

function colorTextPressed(colorPair) {
  var _colorPair$background8;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background8 = colorPair.background) === null || _colorPair$background8 === void 0 ? void 0 : _colorPair$background8.adjust({
    l: l => l - 10
  });
}

function colorsFromOverrides(overrideColors) {
  return Object.keys(overrideColors).reduce((colors, key) => {
    const colorOrPair = overrideColors[key];
    if (colorOrPair == null) return colors;
    const {
      background,
      foreground
    } = colorOrPair;
    return { ...colors,
      [key]: {
        background: background ? normalizeColor(background) : undefined,
        foreground: foreground ? normalizeColor(foreground) : undefined
      }
    };
  }, {});
}

function colorBorder(colorPair) {
  var _colorPair$background9;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background9 = colorPair.background) === null || _colorPair$background9 === void 0 ? void 0 : _colorPair$background9.adjust({
    s: s => s > 50 ? Math.max(s - 15, 0) : s,
    l: l => l > 50 ? Math.max(l - 8.8, 0) : Math.min(l + 11.3, 90)
  });
}

function colorBorderEmphasized(colorPair) {
  var _colorPair$background10;

  return colorPair === null || colorPair === void 0 ? void 0 : (_colorPair$background10 = colorPair.background) === null || _colorPair$background10 === void 0 ? void 0 : _colorPair$background10.adjust({
    s: s => s > 50 ? s : Math.min(s + 15, 100),
    l: l => l > 50 ? Math.max(l - 77.5, 0) : 98.3
  });
}

function normalizeColor(color) {
  if (color instanceof _hsluv.Hsl) return color;
  if (typeof color === 'string') return (0, _hsluv.parseHsl)(color);
  return new _hsluv.Hsl(...color);
}

const COLOR_MAP = {
  /* COLOR CANVAS */
  colorCanvas: ({
    canvas
  }) => canvas === null || canvas === void 0 ? void 0 : canvas.background,
  colorCanvasText: ({
    canvas
  }) => {
    var _canvas$foreground, _canvas$background;

    return (_canvas$foreground = canvas === null || canvas === void 0 ? void 0 : canvas.foreground) !== null && _canvas$foreground !== void 0 ? _canvas$foreground : canvas === null || canvas === void 0 ? void 0 : (_canvas$background = canvas.background) === null || _canvas$background === void 0 ? void 0 : _canvas$background.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)
    });
  },
  colorCanvasTextSubdued: ({
    canvas
  }) => colorTextSubdued(canvas),
  colorCanvasTextEmphasized: ({
    canvas
  }) => colorTextEmphasized(canvas),
  colorCanvasBorder: ({
    canvas
  }) => colorBorder(canvas),
  colorCanvasBorderEmphasized: ({
    canvas
  }) => colorBorderEmphasized(canvas),

  /* COLOR SURFACE 1 */
  colorSurfacePrimary: ({
    surfacePrimary
  }) => surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.background,
  colorSurfacePrimaryDisabled: ({
    surfacePrimary
  }) => {
    var _surfacePrimary$backg;

    return surfacePrimary === null || surfacePrimary === void 0 ? void 0 : (_surfacePrimary$backg = surfacePrimary.background) === null || _surfacePrimary$backg === void 0 ? void 0 : _surfacePrimary$backg.adjust({
      l: l => l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)
    });
  },
  colorSurfacePrimarySubdued: ({
    surfacePrimary
  }) => colorSubdued(surfacePrimary),
  colorSurfacePrimaryText: ({
    surfacePrimary
  }) => {
    var _surfacePrimary$foreg, _surfacePrimary$backg2;

    return (_surfacePrimary$foreg = surfacePrimary === null || surfacePrimary === void 0 ? void 0 : surfacePrimary.foreground) !== null && _surfacePrimary$foreg !== void 0 ? _surfacePrimary$foreg : surfacePrimary === null || surfacePrimary === void 0 ? void 0 : (_surfacePrimary$backg2 = surfacePrimary.background) === null || _surfacePrimary$backg2 === void 0 ? void 0 : _surfacePrimary$backg2.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)
    });
  },
  colorSurfacePrimaryTextSubdued: ({
    surfacePrimary
  }) => colorTextSubdued(surfacePrimary),
  colorSurfacePrimaryTextEmphasized: ({
    surfacePrimary
  }) => colorTextEmphasized(surfacePrimary),
  colorSurfacePrimaryBorder: ({
    surfacePrimary
  }) => colorBorder(surfacePrimary),
  colorSurfacePrimaryBorderEmphasized: ({
    surfacePrimary
  }) => colorBorderEmphasized(surfacePrimary),

  /* COLOR SURFACE 2 */
  colorSurfaceSecondary: ({
    surfaceSecondary
  }) => surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.background,
  colorSurfaceSecondaryDisabled: ({
    surfaceSecondary
  }) => {
    var _surfaceSecondary$bac;

    return surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : (_surfaceSecondary$bac = surfaceSecondary.background) === null || _surfaceSecondary$bac === void 0 ? void 0 : _surfaceSecondary$bac.adjust({
      l: l => l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)
    });
  },
  colorSurfaceSecondarySubdued: ({
    surfaceSecondary
  }) => colorSubdued(surfaceSecondary),
  colorSurfaceSecondaryText: ({
    surfaceSecondary
  }) => {
    var _surfaceSecondary$for, _surfaceSecondary$bac2;

    return (_surfaceSecondary$for = surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : surfaceSecondary.foreground) !== null && _surfaceSecondary$for !== void 0 ? _surfaceSecondary$for : surfaceSecondary === null || surfaceSecondary === void 0 ? void 0 : (_surfaceSecondary$bac2 = surfaceSecondary.background) === null || _surfaceSecondary$bac2 === void 0 ? void 0 : _surfaceSecondary$bac2.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)
    });
  },
  colorSurfaceSecondaryTextSubdued: ({
    surfaceSecondary
  }) => colorTextSubdued(surfaceSecondary),
  colorSurfaceSecondaryTextEmphasized: ({
    surfaceSecondary
  }) => colorTextEmphasized(surfaceSecondary),
  colorSurfaceSecondaryBorder: ({
    surfaceSecondary
  }) => colorBorder(surfaceSecondary),
  colorSurfaceSecondaryBorderEmphasized: ({
    surfaceSecondary
  }) => colorBorderEmphasized(surfaceSecondary),

  /* COLOR SURFACE 3 */
  colorSurfaceTertiary: ({
    surfaceTertiary
  }) => surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.background,
  colorSurfaceTertiaryDisabled: ({
    surfaceTertiary
  }) => {
    var _surfaceTertiary$back;

    return surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : (_surfaceTertiary$back = surfaceTertiary.background) === null || _surfaceTertiary$back === void 0 ? void 0 : _surfaceTertiary$back.adjust({
      l: l => l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)
    });
  },
  colorSurfaceTertiarySubdued: ({
    surfaceTertiary
  }) => colorSubdued(surfaceTertiary),
  colorSurfaceTertiaryText: ({
    surfaceTertiary
  }) => {
    var _surfaceTertiary$fore, _surfaceTertiary$back2;

    return (_surfaceTertiary$fore = surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : surfaceTertiary.foreground) !== null && _surfaceTertiary$fore !== void 0 ? _surfaceTertiary$fore : surfaceTertiary === null || surfaceTertiary === void 0 ? void 0 : (_surfaceTertiary$back2 = surfaceTertiary.background) === null || _surfaceTertiary$back2 === void 0 ? void 0 : _surfaceTertiary$back2.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)
    });
  },
  colorSurfaceTertiaryTextSubdued: ({
    surfaceTertiary
  }) => colorTextSubdued(surfaceTertiary),
  colorSurfaceTertiaryTextEmphasized: ({
    surfaceTertiary
  }) => colorTextEmphasized(surfaceTertiary),
  colorSurfaceTertiaryBorder: ({
    surfaceTertiary
  }) => colorBorder(surfaceTertiary),
  colorSurfaceTertiaryBorderEmphasized: ({
    surfaceTertiary
  }) => colorBorderEmphasized(surfaceTertiary),

  /* COLOR SURFACE 4 */
  colorSurfaceQuaternary: ({
    surfaceQuaternary
  }) => surfaceQuaternary === null || surfaceQuaternary === void 0 ? void 0 : surfaceQuaternary.background,
  colorSurfaceQuaternaryDisabled: ({
    surfaceQuaternary
  }) => {
    var _surfaceQuaternary$ba;

    return surfaceQuaternary === null || surfaceQuaternary === void 0 ? void 0 : (_surfaceQuaternary$ba = surfaceQuaternary.background) === null || _surfaceQuaternary$ba === void 0 ? void 0 : _surfaceQuaternary$ba.adjust({
      l: l => l > 50 ? Math.min(l - 2.5, 97.5) : Math.max(l + 2.5, 2.5)
    });
  },
  colorSurfaceQuaternarySubdued: ({
    surfaceQuaternary
  }) => colorSubdued(surfaceQuaternary),
  colorSurfaceQuaternaryText: ({
    surfaceQuaternary
  }) => {
    var _surfaceQuaternary$fo, _surfaceQuaternary$ba2;

    return (_surfaceQuaternary$fo = surfaceQuaternary === null || surfaceQuaternary === void 0 ? void 0 : surfaceQuaternary.foreground) !== null && _surfaceQuaternary$fo !== void 0 ? _surfaceQuaternary$fo : surfaceQuaternary === null || surfaceQuaternary === void 0 ? void 0 : (_surfaceQuaternary$ba2 = surfaceQuaternary.background) === null || _surfaceQuaternary$ba2 === void 0 ? void 0 : _surfaceQuaternary$ba2.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 62.6, 0) : Math.min(l + 82, 98.3)
    });
  },
  colorSurfaceQuaternaryTextSubdued: ({
    surfaceQuaternary
  }) => colorTextSubdued(surfaceQuaternary),
  colorSurfaceQuaternaryTextEmphasized: ({
    surfaceQuaternary
  }) => colorTextEmphasized(surfaceQuaternary),
  colorSurfaceQuaternaryBorder: ({
    surfaceQuaternary
  }) => colorBorder(surfaceQuaternary),
  colorSurfaceQuaternaryBorderEmphasized: ({
    surfaceQuaternary
  }) => colorBorderEmphasized(surfaceQuaternary),

  /* COLOR PRIMARY */
  colorPrimary: ({
    primary
  }) => primary === null || primary === void 0 ? void 0 : primary.background,
  colorPrimaryHovered: ({
    primary
  }) => colorHovered(primary),
  colorPrimaryPressed: ({
    primary
  }) => colorPressed(primary),
  colorPrimaryText: ({
    primary
  }) => colorText(primary),
  colorPrimaryTextHovered: ({
    primary
  }) => colorTextHovered(primary),
  colorPrimaryTextPressed: ({
    primary
  }) => colorTextPressed(primary),

  /* COLOR SECONDARY */
  colorSecondary: ({
    secondary
  }) => secondary === null || secondary === void 0 ? void 0 : secondary.background,
  colorSecondaryHovered: ({
    secondary
  }) => colorHovered(secondary),
  colorSecondaryPressed: ({
    secondary
  }) => colorPressed(secondary),
  colorSecondaryText: ({
    secondary
  }) => colorText(secondary),
  colorSecondaryTextHovered: ({
    secondary
  }) => colorTextHovered(secondary),
  colorSecondaryTextPressed: ({
    secondary
  }) => colorTextPressed(secondary),

  /* COLOR TERTIARY */
  colorTertiary: ({
    tertiary
  }) => tertiary === null || tertiary === void 0 ? void 0 : tertiary.background,
  colorTertiaryText: ({
    tertiary
  }) => colorText(tertiary),
  colorTertiaryTextSubdued: ({
    tertiary
  }) => {
    var _tertiary$foreground, _tertiary$background;

    return (tertiary === null || tertiary === void 0 ? void 0 : tertiary.foreground) ? tertiary === null || tertiary === void 0 ? void 0 : (_tertiary$foreground = tertiary.foreground) === null || _tertiary$foreground === void 0 ? void 0 : _tertiary$foreground.adjust({
      l: l => Math.min(l + 20, 100)
    }) : tertiary === null || tertiary === void 0 ? void 0 : (_tertiary$background = tertiary.background) === null || _tertiary$background === void 0 ? void 0 : _tertiary$background.adjust({
      s: s => s > 50 ? Math.max(s - 55, 0) : s,
      l: l => l > 50 ? Math.max(l - 49.9, 10) : Math.min(l + 63.2, 90)
    });
  },

  /* COLOR INTERACTIVE */
  colorInteractive: ({
    interactive
  }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
  colorInteractiveHovered: ({
    interactive
  }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
  colorInteractivePressed: ({
    interactive
  }) => interactive === null || interactive === void 0 ? void 0 : interactive.background,
  colorInteractiveText: ({
    interactive
  }) => interactive === null || interactive === void 0 ? void 0 : interactive.foreground,
  colorInteractiveTextHovered: ({
    interactive
  }) => {
    var _interactive$foregrou;

    return interactive === null || interactive === void 0 ? void 0 : (_interactive$foregrou = interactive.foreground) === null || _interactive$foregrou === void 0 ? void 0 : _interactive$foregrou.adjust({
      l: l => l + 10
    });
  },
  colorInteractiveTextPressed: ({
    interactive
  }) => {
    var _interactive$foregrou2;

    return interactive === null || interactive === void 0 ? void 0 : (_interactive$foregrou2 = interactive.foreground) === null || _interactive$foregrou2 === void 0 ? void 0 : _interactive$foregrou2.adjust({
      l: l => l + 10
    });
  },

  /* COLOR CRITICAL */
  colorCritical: ({
    critical
  }) => critical === null || critical === void 0 ? void 0 : critical.background,
  colorCriticalText: ({
    critical
  }) => critical === null || critical === void 0 ? void 0 : critical.foreground,
  colorCriticalBorder: ({
    critical
  }) => {
    var _critical$background;

    return critical === null || critical === void 0 ? void 0 : (_critical$background = critical.background) === null || _critical$background === void 0 ? void 0 : _critical$background.adjust({
      l: l => l - 17.5
    });
  },
  colorCriticalBorderEmphasized: ({
    critical
  }) => critical === null || critical === void 0 ? void 0 : critical.foreground
};
const TYPOGRAPHY_SCALE_MAP = {
  typographySizeXSmall: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(-1, base, ratio) : undefined,
  typographySizeSmall: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(-0.5, base, ratio) : undefined,
  typographySizeDefault: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(0, base, ratio) : undefined,
  typographySizeMedium: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(0.5, base, ratio) : undefined,
  typographySizeLarge: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(1, base, ratio) : undefined,
  typographySizeXLarge: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(2, base, ratio) : undefined,
  typographySizeXXLarge: ({
    base,
    ratio
  }) => base ? (0, _modularScale.modularScale)(3, base, ratio) : undefined
};
const TYPOGRAPHY_SIZE_MAP = {
  xsmall: 'var(--x-typography-size-xsmall)',
  small: 'var(--x-typography-size-small)',
  base: 'var(--x-typography-size-default)',
  medium: 'var(--x-typography-size-medium)',
  large: 'var(--x-typography-size-large)',
  xlarge: 'var(--x-typography-size-xlarge)',
  xxlarge: 'var(--x-typography-size-xxlarge)'
};
const TYPOGRAPHY_CASE_MAP = {
  none: 'none',
  title: 'capitalize',
  upper: 'uppercase',
  lower: 'lowercase'
};
const TYPOGRAPHY_FONTS_MAP = {
  primary: 'var(--x-typography-primary-fonts)',
  secondary: 'var(--x-typography-secondary-fonts)'
};
const TYPOGRAPHY_KERNING_MAP = {
  base: 'normal',
  loose: '0.125em',
  xloose: '0.16em'
};
const TYPOGRAPHY_LINE_SIZE_MAP = {
  base: '1.3',
  large: '1.5'
};
const TYPOGRAPHY_PRIMARY_WEIGHT_MAP = {
  base: 'var(--x-typography-primary-weight-base)',
  bold: 'var(--x-typography-primary-weight-bold)'
};
const TYPOGRAPHY_SECONDARY_WEIGHT_MAP = {
  base: 'var(--x-typography-secondary-weight-base)',
  bold: 'var(--x-typography-secondary-weight-bold)'
};
const SPACING_RATIO = 1.225;
const SPACING_MAP = {
  spacingTight4x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(-5, base, SPACING_RATIO) : undefined,
  spacingTight3x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(-4, base, SPACING_RATIO) : undefined,
  spacingTight2x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(-3, base, SPACING_RATIO) : undefined,
  spacingTight1x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(-2, base, SPACING_RATIO) : undefined,
  spacingTight: ({
    base
  }) => base ? (0, _modularScale.modularScale)(-1, base, SPACING_RATIO) : undefined,
  spacingBase: ({
    base
  }) => base ? (0, _modularScale.modularScale)(0, base, SPACING_RATIO) : undefined,
  spacingLoose: ({
    base
  }) => base ? (0, _modularScale.modularScale)(1, base, SPACING_RATIO) : undefined,
  spacingLoose1x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(2, base, SPACING_RATIO) : undefined,
  spacingLoose2x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(3, base, SPACING_RATIO) : undefined,
  spacingLoose3x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(4, base, SPACING_RATIO) : undefined,
  spacingLoose4x: ({
    base
  }) => base ? (0, _modularScale.modularScale)(5, base, SPACING_RATIO) : undefined
};
const SIMPLE_BORDER_RADIUS_MAP = {
  none: 'var(--x-border-radius-none)',
  base: 'var(--x-border-radius-base)'
};
const BORDER_RADIUS_MAP = { ...SIMPLE_BORDER_RADIUS_MAP,
  tight: 'var(--x-border-radius-tight)',
  fullyRounded: 'var(--x-border-radius-fully-rounded)'
};
const BORDER_MAP = {
  full: 'var(--x-border-full)',
  blockEnd: 'var(--x-border-block-end)',
  none: 'var(--x-border-none)'
};
const OPTION_LIST_GAP_MAP = {
  base: 'var(--x-spacing-base)',
  tight: 'var(--x-spacing-tight4x)',
  none: '0'
};
const MONEY_LINES_GAP_MAP = {
  base: 'var(--x-spacing-tight)',
  tight: 'var(--x-spacing-tight1x)',
  none: '0'
};
const MONEY_LINES_SEPARATOR_GAP_MAP = {
  base: 'var(--x-spacing-loose1x)',
  tight: 'var(--x-spacing-base)',
  none: '0'
};
const REVIEW_BLOCK_GAP_MAP = {
  base: 'var(--x-spacing-base)',
  tight: 'var(--x-spacing-tight4x)',
  none: '0'
};
const BUYER_JOURNEY_GAP_MAP = {
  base: 'var(--x-spacing-tight1x)',
  loose: 'var(--x-spacing-loose2x)'
};
const SPACING_VAR_MAP = {
  none: '0',
  tight4x: 'var(--x-spacing-tight4x)',
  tight3x: 'var(--x-spacing-tight3x)',
  tight2x: 'var(--x-spacing-tight2x)',
  tight1x: 'var(--x-spacing-tight1x)',
  tight: 'var(--x-spacing-tight)',
  base: 'var(--x-spacing-base)',
  loose: 'var(--x-spacing-loose)',
  loose1x: 'var(--x-spacing-loose1x)',
  loose2x: 'var(--x-spacing-loose2x)',
  loose3x: 'var(--x-spacing-loose3x)',
  loose4x: 'var(--x-spacing-loose4x)'
};

function customPropertiesFromThemeConfiguration({
  global,
  buyerJourney,
  colors,
  typographyScale,
  typographyPrimary,
  typographySecondary,
  controls,
  textFields,
  select,
  optionList,
  checkbox,
  moneyLines,
  moneySummary,
  reviewBlock,
  primaryButton,
  secondaryButton,
  tag,
  banner,
  typographyStyle1,
  typographyStyle2,
  typographyStyle3,
  typographyStyle4,
  typographyStyle5,
  typographyStyle6,
  typographyStyle7,
  typographyStyle8,
  typographyStyle9
}) {
  var _typographyPrimary$fo, _typographyPrimary$we, _typographyPrimary$we2, _typographySecondary$, _typographySecondary$2, _typographySecondary$3;

  const globalTypographyLetterCase = maybeInMap(TYPOGRAPHY_CASE_MAP)(global.typographyLetterCase);
  const globalTypographyLineSize = maybeInMap(TYPOGRAPHY_LINE_SIZE_MAP)(global.typographyLineSize);
  const globalTypographyKerning = maybeInMap(TYPOGRAPHY_KERNING_MAP)(global.typographyKerning);
  const globalBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(global.borderRadius);
  const controlBorderRadius = maybeInMap(SIMPLE_BORDER_RADIUS_MAP)(controls.borderRadius);
  const textFieldBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(textFields.borderRadius);
  const selectBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(select.borderRadius);
  const optionListBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(optionList.borderRadius);
  const checkboxBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(checkbox.borderRadius);
  const reviewBlockBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(reviewBlock.borderRadius);
  const [textFieldBorder, selectBorder, checkboxBorder] = [textFields.border, select.border, checkbox.border].map(maybeInMap(BORDER_MAP));
  const typographyPrimaryFonts = (_typographyPrimary$fo = typographyPrimary.fonts) !== null && _typographyPrimary$fo !== void 0 ? _typographyPrimary$fo : undefined;
  const typographyPrimaryWeightBase = (_typographyPrimary$we = typographyPrimary.weightBase) !== null && _typographyPrimary$we !== void 0 ? _typographyPrimary$we : undefined;
  const typographyPrimaryWeightBold = (_typographyPrimary$we2 = typographyPrimary.weightBold) !== null && _typographyPrimary$we2 !== void 0 ? _typographyPrimary$we2 : undefined;
  const typographySecondaryFonts = (_typographySecondary$ = typographySecondary.fonts) !== null && _typographySecondary$ !== void 0 ? _typographySecondary$ : undefined;
  const typographySecondaryWeightBase = (_typographySecondary$2 = typographySecondary.weightBase) !== null && _typographySecondary$2 !== void 0 ? _typographySecondary$2 : undefined;
  const typographySecondaryWeightBold = (_typographySecondary$3 = typographySecondary.weightBold) !== null && _typographySecondary$3 !== void 0 ? _typographySecondary$3 : undefined;
  const optionListBlockGap = maybeInMap(OPTION_LIST_GAP_MAP)(optionList.gap);
  const moneyLinesBlockGap = maybeInMap(MONEY_LINES_GAP_MAP)(moneyLines.gap);
  const moneyLinesSeparatorBlockGap = maybeInMap(MONEY_LINES_SEPARATOR_GAP_MAP)(moneyLines.gap);
  const buyerJourneyInlineGap = maybeInMap(BUYER_JOURNEY_GAP_MAP)(buyerJourney.gap);
  const reviewBlockBlockGap = maybeInMap(REVIEW_BLOCK_GAP_MAP)(reviewBlock.gap);
  const reviewBlockBorder = maybeInMap(BORDER_MAP)(reviewBlock.border);
  const [style1TypographySize, style1TypographyCase, style1TypographyFonts, style1TypographyWeight, style1TypographyLineSize, style1TypographyKerning, style2TypographySize, style2TypographyCase, style2TypographyFonts, style2TypographyWeight, style2TypographyLineSize, style2TypographyKerning, style3TypographySize, style3TypographyCase, style3TypographyFonts, style3TypographyWeight, style3TypographyLineSize, style3TypographyKerning, style4TypographySize, style4TypographyCase, style4TypographyFonts, style4TypographyWeight, style4TypographyLineSize, style4TypographyKerning, style5TypographySize, style5TypographyCase, style5TypographyFonts, style5TypographyWeight, style5TypographyLineSize, style5TypographyKerning, style6TypographySize, style6TypographyCase, style6TypographyFonts, style6TypographyWeight, style6TypographyLineSize, style6TypographyKerning, style7TypographySize, style7TypographyCase, style7TypographyFonts, style7TypographyWeight, style7TypographyLineSize, style7TypographyKerning, style8TypographySize, style8TypographyCase, style8TypographyFonts, style8TypographyWeight, style8TypographyLineSize, style8TypographyKerning, style9TypographySize, style9TypographyCase, style9TypographyFonts, style9TypographyWeight, style9TypographyLineSize, style9TypographyKerning] = [typographyStyle1, typographyStyle2, typographyStyle3, typographyStyle4, typographyStyle5, typographyStyle6, typographyStyle7, typographyStyle8, typographyStyle9].map(style => [maybeInMap(TYPOGRAPHY_SIZE_MAP)(style.size), maybeInMap(TYPOGRAPHY_CASE_MAP)(style.letterCase), maybeInMap(TYPOGRAPHY_FONTS_MAP)(style.fonts), style.weight ? typographyWeightMapping(style.fonts ? style.fonts : 'secondary', style.weight) : undefined, maybeInMap(TYPOGRAPHY_LINE_SIZE_MAP)(style.lineSize), maybeInMap(TYPOGRAPHY_KERNING_MAP)(style.kerning)]).reduce((accumulator, array) => [...accumulator, ...array], []);
  const primaryButtonBlockPadding = maybeInMap(SPACING_VAR_MAP)(primaryButton.blockPadding);
  const primaryButtonInlinePadding = maybeInMap(SPACING_VAR_MAP)(primaryButton.inlinePadding);
  const secondaryButtonBlockPadding = maybeInMap(SPACING_VAR_MAP)(secondaryButton.blockPadding);
  const secondaryButtonInlinePadding = maybeInMap(SPACING_VAR_MAP)(secondaryButton.inlinePadding);
  const moneyLinesBlockPadding = maybeInMap(SPACING_VAR_MAP)(moneyLines.blockPadding);
  const moneyLinesInlinePadding = maybeInMap(SPACING_VAR_MAP)(moneyLines.inlinePadding);
  const moneySummaryBlockPadding = maybeInMap(SPACING_VAR_MAP)(moneySummary.blockPadding);
  const moneySummaryInlinePadding = maybeInMap(SPACING_VAR_MAP)(moneySummary.inlinePadding);
  const optionListBlockPadding = maybeInMap(SPACING_VAR_MAP)(optionList.blockPadding);
  const optionListInlinePadding = maybeInMap(SPACING_VAR_MAP)(optionList.inlinePadding);
  const tagBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(tag.borderRadius);
  /** To avoid an oval-y shape caused by sub-pixel dimensions, we need JS to floor the size of our radio buttons. */

  const radioSize = typographyScale.base ? `${Math.floor(parseFloat(typographyScale.base.toString()) * RADIO_SCALE)}px` : undefined;
  /** To avoid an rectangular shape caused by sub-pixel dimensions, we need JS to floor the size of our checkboxes. */

  const checkboxSize = typographyScale.base ? `${Math.floor(parseFloat(typographyScale.base.toString()) * CHECKBOX_SCALE)}px` : undefined;
  const bannerBorder = maybeInMap(BORDER_MAP)(banner.border);
  const bannerBorderRadius = maybeInMap(BORDER_RADIUS_MAP)(banner.borderRadius);
  const customProperties = { ...customPropertiesFromRoleColors(colorsFromOverrides(colors)),
    ...customPropertiesFromTypographyScale(typographyScale),
    ...customPropertiesFromSpacing(typographyScale),
    typographyPrimaryFonts,
    typographyPrimaryWeightBase,
    typographyPrimaryWeightBold,
    typographySecondaryFonts,
    typographySecondaryWeightBase,
    typographySecondaryWeightBold,
    globalTypographyLetterCase,
    globalTypographyLineSize,
    globalTypographyKerning,
    globalBorderRadius,
    controlBorderRadius,
    checkboxBorder,
    checkboxBorderRadius,
    textFieldBorder,
    textFieldBorderRadius,
    selectBorderRadius,
    selectBorder,
    optionListBorderRadius,
    optionListBlockGap,
    reviewBlockBorderRadius,
    reviewBlockBlockGap,
    reviewBlockBorder,
    moneyLinesBlockGap,
    moneyLinesSeparatorBlockGap,
    buyerJourneyInlineGap,
    style1TypographySize,
    style1TypographyCase,
    style1TypographyFonts,
    style1TypographyWeight,
    style1TypographyLineSize,
    style1TypographyKerning,
    style2TypographySize,
    style2TypographyCase,
    style2TypographyFonts,
    style2TypographyWeight,
    style2TypographyLineSize,
    style2TypographyKerning,
    style3TypographySize,
    style3TypographyCase,
    style3TypographyFonts,
    style3TypographyWeight,
    style3TypographyLineSize,
    style3TypographyKerning,
    style4TypographySize,
    style4TypographyCase,
    style4TypographyFonts,
    style4TypographyWeight,
    style4TypographyLineSize,
    style4TypographyKerning,
    style5TypographySize,
    style5TypographyCase,
    style5TypographyFonts,
    style5TypographyWeight,
    style5TypographyLineSize,
    style5TypographyKerning,
    style6TypographySize,
    style6TypographyCase,
    style6TypographyFonts,
    style6TypographyWeight,
    style6TypographyLineSize,
    style6TypographyKerning,
    style7TypographySize,
    style7TypographyCase,
    style7TypographyFonts,
    style7TypographyWeight,
    style7TypographyLineSize,
    style7TypographyKerning,
    style8TypographySize,
    style8TypographyCase,
    style8TypographyFonts,
    style8TypographyWeight,
    style8TypographyLineSize,
    style8TypographyKerning,
    style9TypographySize,
    style9TypographyCase,
    style9TypographyFonts,
    style9TypographyWeight,
    style9TypographyLineSize,
    style9TypographyKerning,
    primaryButtonBlockPadding,
    primaryButtonInlinePadding,
    secondaryButtonBlockPadding,
    secondaryButtonInlinePadding,
    moneyLinesBlockPadding,
    moneyLinesInlinePadding,
    moneySummaryBlockPadding,
    moneySummaryInlinePadding,
    optionListBlockPadding,
    optionListInlinePadding,
    tagBorderRadius,
    radioSize,
    checkboxSize,
    bannerBorder,
    bannerBorderRadius
  };

  for (const key of Object.keys(customProperties)) {
    if (customProperties[key] == null) {
      delete customProperties[key];
    }
  }

  return customProperties;
}

function customPropertiesFromRoleColors(colors) {
  const customProperties = {};

  for (const property of Object.keys(COLOR_MAP)) {
    var _COLOR_MAP$property;

    const color = (_COLOR_MAP$property = COLOR_MAP[property]) === null || _COLOR_MAP$property === void 0 ? void 0 : _COLOR_MAP$property.call(COLOR_MAP, colors);
    if (color != null) customProperties[property] = (0, _hsluv.toRgb)(color);
  }

  return customProperties;
}

function customPropertiesFromTypographyScale(scale) {
  const customProperties = {};

  for (const property of Object.keys(TYPOGRAPHY_SCALE_MAP)) {
    var _TYPOGRAPHY_SCALE_MAP;

    const fontSize = (_TYPOGRAPHY_SCALE_MAP = TYPOGRAPHY_SCALE_MAP[property]) === null || _TYPOGRAPHY_SCALE_MAP === void 0 ? void 0 : _TYPOGRAPHY_SCALE_MAP.call(TYPOGRAPHY_SCALE_MAP, scale);
    if (fontSize != null) customProperties[property] = fontSize;
  }

  return customProperties;
}

function customPropertiesFromSpacing(scale) {
  const customProperties = {};

  for (const property of Object.keys(SPACING_MAP)) {
    var _SPACING_MAP$property;

    const spacing = (_SPACING_MAP$property = SPACING_MAP[property]) === null || _SPACING_MAP$property === void 0 ? void 0 : _SPACING_MAP$property.call(SPACING_MAP, scale);
    if (spacing != null) customProperties[property] = spacing;
  }

  return customProperties;
}

function typographyWeightMapping(fontStack, weight) {
  return fontStack === 'primary' ? TYPOGRAPHY_PRIMARY_WEIGHT_MAP[weight] : TYPOGRAPHY_SECONDARY_WEIGHT_MAP[weight];
}

function maybeInMap(map) {
  return value => value ? map[value] : undefined;
}