"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _ = require(".");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  source: _faker.default.internet.url(),
  description: _faker.default.lorem.words(2)
};
describe('Thumbnail', () => {
  it('renders an <img /> with an src and an alt attributes', () => {
    const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
      badge: "1"
    })));
    expect(thumbnail).toContainReactComponent('img', {
      src: defaultProps.source,
      alt: defaultProps.description
    });
  });
  describe('sources prop', () => {
    it('does not render srcset if sources are undefined', () => {
      const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, defaultProps));
      expect(thumbnail).not.toContainReactComponent('img', {
        srcSet: expect.anything()
      });
    });
    it('renders a srcset when provided with sources', () => {
      const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
        sources: ['a 1x', 'b 2x', 'c 3x']
      })));
      expect(thumbnail).toContainReactComponent('img', {
        srcSet: 'a 1x, b 2x, c 3x'
      });
    });
  });
  it('renders a badge when provided as a string', () => {
    const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
      badge: "1"
    })));
    expect(thumbnail.find('span')).toContainReactText('1');
  });
  it('renders a badge when provided as a number', () => {
    const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
      badge: 0
    })));
    expect(thumbnail.find('span')).toContainReactText('0');
  });
  it("doesn't render a badge when not provided", () => {
    const thumbnail = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, defaultProps));
    expect(thumbnail).not.toContainReactComponent('span');
  });
});