"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../test-utilities");
const Text_1 = require("../Text");
const MoneyLine_1 = require("./MoneyLine");
const defaultProps = {
    label: faker_1.default.random.word(),
    value: faker_1.default.random.number().toString(),
};
describe('<MoneyLine />', () => {
    it('renders a label', () => {
        const label = faker_1.default.random.word();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine {...defaultProps} label={label}/>);
        expect(moneyLine).toContainReactText(label);
    });
    it('renders a value', () => {
        const value = faker_1.default.random.number().toString();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine {...defaultProps} value={value}/>);
        expect(moneyLine).toContainReactText(value);
    });
    it('renders a subdued value if subdued', () => {
        const value = faker_1.default.random.number().toString();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine {...defaultProps} value={value} subdued/>);
        expect(moneyLine).toContainReactComponent(Text_1.Text, {
            subdued: true,
            children: value,
        });
    });
    it('renders its children', () => {
        function Child() {
            return <div />;
        }
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine {...defaultProps}>
        <Child />
      </MoneyLine_1.MoneyLine>);
        expect(moneyLine).toContainReactComponent(Child);
    });
});
