"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.computeOffsets = exports.roundOffsets = void 0;
const SPACING = 10;
// Round the offsets to the nearest suitable subpixel
// based on the device pixel ratio.
function roundOffsets({ x, y }) {
    const dpr = window.devicePixelRatio || 1;
    return {
        x: Math.round(x * dpr) / dpr || 0,
        y: Math.round(y * dpr) / dpr || 0,
    };
}
exports.roundOffsets = roundOffsets;
function computeOffsets(placement, popperRect, referenceRect, { offset = 0, preventOverflow = false, sameInlineSize = false } = {}) {
    let offsets = { x: 0, y: 0 };
    let clipping = { left: 0, right: 0 };
    let spacing = 0;
    if (!popperRect || !referenceRect) {
        return { offsets, clipping, spacing };
    }
    const commonX = sameInlineSize
        ? referenceRect.left
        : referenceRect.left + referenceRect.width / 2 - popperRect.width / 2;
    switch (placement) {
        case 'blockStart':
            offsets = {
                x: commonX,
                y: referenceRect.top - popperRect.height - offset,
            };
            break;
        case 'blockEnd':
            offsets = {
                x: commonX,
                y: referenceRect.bottom + offset,
            };
            break;
    }
    if (preventOverflow) {
        clipping = getClipping(offsets, popperRect);
        if (clipping.right && !clipping.left) {
            offsets.x += clipping.right;
            spacing = -SPACING;
        }
        if (!clipping.right && clipping.left) {
            offsets.x = 0;
            spacing = SPACING;
        }
    }
    return { offsets, clipping, spacing };
}
exports.computeOffsets = computeOffsets;
function getClipping(offsets, popperRect) {
    const viewportWidth = document.documentElement.clientWidth;
    const elementWidth = offsets.x + popperRect.width;
    let clipping = { left: 0, right: 0 };
    if (elementWidth > viewportWidth) {
        clipping = Object.assign(Object.assign({}, clipping), { right: viewportWidth - elementWidth });
    }
    if (offsets.x < 0) {
        clipping = Object.assign(Object.assign({}, clipping), { left: -offsets.x });
    }
    return clipping;
}
