import React from 'react';
import { TextFieldProps } from '@shopify/argo-checkout';
export interface Props extends TextFieldProps {
    accessibilityDescription?: string;
    autofocus?: boolean;
    /**
     * In rare cases, like the PhoneField component, we completely control state.
     * In those cases, there is never a difference between the `value` prop of the field
     * and the current value in the field, and so this component never considers the
     * field to have changed. Use the `controlledValue` prop to provide the value that
     * should be shown to the buyer in those circumstances, but where the `value` prop
     * will continue to be used as the comparison value to determine whether the field
     * has changed (this will usually be set to the last committed, unformatted value
     * for the controlled input).
     */
    controlledValue?: string;
    disabled?: boolean;
    readonly?: boolean;
}
/**
 * A text field is an input field that merchants can type into.
 */
export declare const TextField: React.ForwardRefExoticComponent<Props & React.RefAttributes<unknown>>;
interface FieldProps extends Omit<Props, 'id'> {
    id: string;
    ariaActiveDescendant?: string;
    ariaAutocomplete?: string;
    ariaControls?: string;
    ariaDescribedBy?: string;
    ariaExpanded?: boolean;
    autofocus?: boolean;
    role?: string;
    onKeyDown?(event: React.KeyboardEvent<HTMLInputElement>): void;
}
export declare const Field: React.ForwardRefExoticComponent<FieldProps & React.RefAttributes<unknown>>;
export {};
