"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.themeWithKnobs = void 0;
const react_1 = __importDefault(require("react"));
const addon_knobs_1 = require("@storybook/addon-knobs");
const hsluv_1 = require("hsluv");
const __1 = require("..");
var Group;
(function (Group) {
    Group["TextField"] = "Text field";
    Group["Select"] = "Select";
    Group["Breadcrumb"] = "Breadcrumb";
    Group["Actions"] = "Actions";
    Group["HeadingLevel1"] = "Heading level 1";
    Group["HeadingLevel2"] = "Heading level 2";
    Group["HeadingLevel3"] = "Heading level 3";
    Group["Checkbox"] = "Checkbox";
    Group["PrimaryButton"] = "Primary button";
    Group["SecondaryButton"] = "Secondary button";
    Group["FormLayout"] = "Form layout";
    Group["Tag"] = "Tag";
    Group["Tooltip"] = "Tooltip";
    Group["Banner"] = "Banner";
    Group["OptionList"] = "Option list";
    Group["Style"] = "Style";
    Group["Color"] = "Color";
    Group["Typography"] = "Typography";
})(Group || (Group = {}));
var Label;
(function (Label) {
    Label["Border"] = "Border";
    Label["BorderRadius"] = "Border radius";
    Label["LabelPosition"] = "Label position";
    Label["Style"] = "Style";
    Label["ErrorIndentation"] = "Error indentation";
    Label["BlockPadding"] = "Block padding";
    Label["InlinePadding"] = "Inline padding";
    Label["LoadingStyle"] = "Loading style";
})(Label || (Label = {}));
var Action;
(function (Action) {
    Action["Display"] = "Display";
})(Action || (Action = {}));
var Breadcrumb;
(function (Breadcrumb) {
    Breadcrumb["Gap"] = "Gap";
    Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
    Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));
const SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
const BORDER_RADIUS_OPTIONS = optionify([
    'none',
    'tight',
    'base',
    'fullyRounded',
]);
const SIMPLE_BORDER_OPTIONS = optionify(['full', 'none']);
const BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
const LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
const ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
const BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
const NUMBER_STYLE_OPTIONS = optionify([
    'none',
    'decimal',
    'decimalLeadingZero',
]);
const STYLE_OPTIONS = optionify(['style1']);
const SIZE_OPTIONS = optionify([
    'base',
    'xsmall',
    'small',
    'medium',
    'large',
    'xlarge',
    'xxlarge',
]);
const LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
const FONT_OPTIONS = optionify(['primary', 'secondary']);
const WEIGHT_OPTIONS = optionify(['base', 'bold']);
const LINE_SIZE_OPTIONS = optionify(['base', 'large']);
const KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);
const SPACING_OPTIONS = optionify([
    'none',
    'tight4x',
    'tight3x',
    'tight2x',
    'tight1x',
    'tight',
    'base',
    'loose',
    'loose1x',
    'loose2x',
    'loose3x',
    'loose4x',
]);
const SIMPLE_SPACING_OPTIONS = optionify(['tight', 'base']);
const LOADING_STYLE_OPTIONS = optionify(['spinner', 'progressBar']);
const ERROR_INDENTATION_OPTIONS = optionify(['none', 'toText']);
const OPACITY_OPTIONS = optionify(['translucent', 'opaque']);
const TEXT_ALIGNMENT_OPTIONS = optionify(['start', 'center']);
const OPTION_LIST_BORDER_OPTIONS = optionify(['full', 'none', 'inner']);
const BORDER_STYLE_OPTIONS = optionify(['base', 'dotted']);
const UNDEFINED = '';
const FONT_WEIGHT_OPTIONS = optionify([
    '100',
    '200',
    '300',
    '400',
    '500',
    '600',
    '700',
    '800',
    '900',
]);
function themeWithKnobs(...picks) {
    return (storyFn) => <ThemeWithKnobs pick={picks}>{storyFn()}</ThemeWithKnobs>;
}
exports.themeWithKnobs = themeWithKnobs;
function ThemeWithKnobs({ pick = [], children }) {
    const textFields = {
        border: undefined,
        labelPosition: undefined,
        errorIndentation: undefined,
    };
    const selects = {
        border: undefined,
        labelPosition: undefined,
        errorIndentation: undefined,
    };
    const actions = { display: undefined };
    const buyerJourney = {
        gap: undefined,
        chevronIconSeparator: true,
        numberStyle: undefined,
        typographyStyle: undefined,
    };
    const headingLevel1 = { typographyStyle: undefined };
    const headingLevel2 = { typographyStyle: undefined };
    const headingLevel3 = { typographyStyle: undefined };
    const checkbox = {
        borderRadius: undefined,
        errorIndentation: undefined,
    };
    const primaryButton = {
        blockPadding: undefined,
        inlinePadding: undefined,
        typographyStyle: undefined,
        loadingStyle: undefined,
    };
    const secondaryButton = {
        blockPadding: undefined,
        inlinePadding: undefined,
        typographyStyle: undefined,
        loadingStyle: undefined,
    };
    const formLayout = {
        spacing: undefined,
    };
    const tag = {
        borderRadius: undefined,
    };
    const tooltip = {
        borderRadius: undefined,
        opacity: undefined,
        textAlignment: undefined,
    };
    const banner = {
        border: undefined,
        borderRadius: undefined,
    };
    const optionList = {
        border: undefined,
        borderRadius: undefined,
        borderStyle: undefined,
        gap: undefined,
        blockPadding: undefined,
        inlinePadding: undefined,
        typographyStyle: undefined,
    };
    if (pick.includes('textFields')) {
        textFields.border = addon_knobs_1.select(Label.Border, BORDER_OPTIONS, textFields.border, Group.TextField);
        textFields.labelPosition = addon_knobs_1.select(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFields.labelPosition, Group.TextField);
        textFields.errorIndentation = addon_knobs_1.select(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, textFields.errorIndentation, Group.TextField);
    }
    if (pick.includes('select')) {
        selects.border = addon_knobs_1.select(Label.Border, BORDER_OPTIONS, selects.border, Group.Select);
        selects.labelPosition = addon_knobs_1.select(Label.LabelPosition, LABEL_POSITION_OPTIONS, selects.labelPosition, Group.Select);
        selects.errorIndentation = addon_knobs_1.select(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, selects.errorIndentation, Group.Select);
    }
    if (pick.includes('actions')) {
        actions.display = addon_knobs_1.select(Action.Display, ACTIONS_DISPLAY_OPTIONS, actions.display, Group.Actions);
    }
    if (pick.includes('buyerJourney')) {
        buyerJourney.gap = addon_knobs_1.select(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, buyerJourney.gap, Group.Breadcrumb);
        buyerJourney.chevronIconSeparator = addon_knobs_1.boolean(Breadcrumb.ChevronIconSeparator, buyerJourney.chevronIconSeparator, Group.Breadcrumb);
        buyerJourney.numberStyle = addon_knobs_1.select(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, buyerJourney.numberStyle, Group.Breadcrumb);
        buyerJourney.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, buyerJourney.typographyStyle, Group.Breadcrumb);
    }
    if (pick.includes('checkbox')) {
        checkbox.borderRadius = addon_knobs_1.select(Label.BorderRadius, SIMPLE_BORDER_RADIUS_OPTIONS, checkbox.borderRadius, Group.Checkbox);
        checkbox.errorIndentation = addon_knobs_1.select(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, checkbox.errorIndentation, Group.Checkbox);
    }
    if (pick.includes('banner')) {
        banner.border = addon_knobs_1.select(Label.Border, SIMPLE_BORDER_OPTIONS, banner.border, Group.Banner);
        banner.borderRadius = addon_knobs_1.select(Label.BorderRadius, BORDER_RADIUS_OPTIONS, banner.borderRadius, Group.Banner);
    }
    if (pick.includes('optionList')) {
        optionList.borderRadius = addon_knobs_1.select(Label.BorderRadius, BORDER_RADIUS_OPTIONS, optionList.borderRadius, Group.OptionList);
        optionList.border = addon_knobs_1.select(Label.Border, OPTION_LIST_BORDER_OPTIONS, optionList.border, Group.OptionList);
        optionList.borderStyle = addon_knobs_1.select('Border style', BORDER_STYLE_OPTIONS, optionList.borderStyle, Group.OptionList);
        optionList.gap = addon_knobs_1.select('Gap', optionify(['none', 'tight', 'base']), optionList.gap, Group.OptionList);
        optionList.blockPadding = addon_knobs_1.select(Label.BlockPadding, SPACING_OPTIONS, optionList.blockPadding, Group.OptionList);
        optionList.inlinePadding = addon_knobs_1.select(Label.InlinePadding, SPACING_OPTIONS, optionList.inlinePadding, Group.OptionList);
        optionList.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, optionList.typographyStyle, Group.OptionList);
    }
    if (pick.includes('headingLevel1')) {
        headingLevel1.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, headingLevel1.typographyStyle, Group.HeadingLevel1);
    }
    if (pick.includes('headingLevel2')) {
        headingLevel2.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, headingLevel2.typographyStyle, Group.HeadingLevel2);
    }
    if (pick.includes('headingLevel3')) {
        headingLevel3.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, headingLevel3.typographyStyle, Group.HeadingLevel3);
    }
    if (pick.includes('primaryButton')) {
        primaryButton.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, primaryButton.typographyStyle, Group.PrimaryButton);
        primaryButton.blockPadding = addon_knobs_1.select(Label.BlockPadding, SPACING_OPTIONS, primaryButton.blockPadding, Group.PrimaryButton);
        primaryButton.inlinePadding = addon_knobs_1.select(Label.InlinePadding, SPACING_OPTIONS, primaryButton.inlinePadding, Group.PrimaryButton);
        primaryButton.loadingStyle = addon_knobs_1.select(Label.LoadingStyle, LOADING_STYLE_OPTIONS, primaryButton.loadingStyle, Group.PrimaryButton);
    }
    if (pick.includes('secondaryButton')) {
        secondaryButton.typographyStyle = addon_knobs_1.select(Label.Style, STYLE_OPTIONS, secondaryButton.typographyStyle, Group.SecondaryButton);
        secondaryButton.blockPadding = addon_knobs_1.select(Label.BlockPadding, SPACING_OPTIONS, secondaryButton.blockPadding, Group.SecondaryButton);
        secondaryButton.inlinePadding = addon_knobs_1.select(Label.InlinePadding, SPACING_OPTIONS, secondaryButton.inlinePadding, Group.SecondaryButton);
        secondaryButton.loadingStyle = addon_knobs_1.select(Label.LoadingStyle, LOADING_STYLE_OPTIONS, secondaryButton.loadingStyle, Group.SecondaryButton);
    }
    if (pick.includes('formLayout')) {
        formLayout.spacing = addon_knobs_1.select('Spacing', SIMPLE_SPACING_OPTIONS, formLayout.spacing, Group.FormLayout);
    }
    if (pick.includes('tag')) {
        tag.borderRadius = addon_knobs_1.select(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tag.borderRadius, Group.Tag);
    }
    if (pick.includes('tooltip')) {
        tooltip.borderRadius = addon_knobs_1.select(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tooltip.borderRadius, Group.Tooltip);
        tooltip.opacity = addon_knobs_1.select('Opacity', OPACITY_OPTIONS, tooltip.opacity, Group.Tooltip);
        tooltip.textAlignment = addon_knobs_1.select('Text alignment', TEXT_ALIGNMENT_OPTIONS, tooltip.textAlignment, Group.Tooltip);
    }
    const theme = __1.createTheme({
        textFields,
        select: selects,
        actions,
        buyerJourney,
        headingLevel1,
        headingLevel2,
        headingLevel3,
        checkbox,
        primaryButton,
        secondaryButton,
        formLayout,
        tag,
        tooltip,
        banner,
        optionList,
        typographyStyle1: {
            size: addon_knobs_1.select(`Size`, SIZE_OPTIONS, undefined, Group.Style),
            letterCase: addon_knobs_1.select(`Letter case`, LETTER_CASE_OPTIONS, undefined, Group.Style),
            fonts: addon_knobs_1.select(`Font`, FONT_OPTIONS, undefined, Group.Style),
            weight: addon_knobs_1.select(`Weight`, WEIGHT_OPTIONS, undefined, Group.Style),
            lineSize: addon_knobs_1.select(`Line size`, LINE_SIZE_OPTIONS, undefined, Group.Style),
            kerning: addon_knobs_1.select(`Kerning`, KERNING_OPTIONS, undefined, Group.Style),
        },
        typographyScale: {
            base: addon_knobs_1.number('Base size', 14, {}, Group.Typography),
            ratio: addon_knobs_1.number('Scale ratio', 1.285, { step: 0.001 }, Group.Typography),
        },
        typographyPrimary: {
            fonts: addon_knobs_1.text('Primary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
            weightBase: addon_knobs_1.select('Primary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
            weightBold: addon_knobs_1.select('Primary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
        },
        typographySecondary: {
            fonts: addon_knobs_1.text('Secondary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
            weightBase: addon_knobs_1.select('Secondary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
            weightBold: addon_knobs_1.select('Secondary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
        },
        colors: {
            canvas: hsluvColorPair('Canvas'),
            surfacePrimary: hsluvColorPair('Surface primary'),
            surfaceSecondary: hsluvColorPair('Surface secondary'),
            surfaceTertiary: hsluvColorPair('Surface tertiary'),
            surfaceQuaternary: hsluvColorPair('Surface quaternary'),
            primary: hsluvColorPair('Primary'),
            secondary: hsluvColorPair('Secondary'),
            tertiary: hsluvColorPair('Tertiary'),
            interactive: hsluvColorPair('Interactive'),
            success: hsluvColorPair('Success'),
            critical: hsluvColorPair('Critical'),
        },
    });
    return <__1.Theme theme={theme}>{children}</__1.Theme>;
}
function optionify(array) {
    return array.reduce((acc, value) => (Object.assign(Object.assign({}, acc), { [value]: value })), {
        ' ': undefined,
    });
}
function toHsluv(str) {
    if (str === UNDEFINED)
        return undefined;
    const rgb = str
        .slice(5, -1)
        .split(',')
        .slice(0, 3)
        .map(Number)
        .map((num) => num / 255);
    return hsluv_1.rgbToHsluv(rgb);
}
function hsluvColor(name) {
    return toHsluv(addon_knobs_1.color(name, UNDEFINED, Group.Color));
}
function hsluvColorPair(name) {
    return {
        background: hsluvColor(`${name} background`),
        foreground: hsluvColor(`${name} foreground`),
    };
}
